# spatstat NAMESPACE file

import(stats,graphics,grDevices,utils,methods)
import(spatstat.utils,spatstat.data)
import(polyclip,goftest)
import(Matrix,nlme,rpart)
importFrom(deldir,
           deldir,duplicatedxy,tile.list)
importFrom(abind,abind)
importFrom(tensor,tensor)
importFrom(mgcv,
           gam,gam.control,anova.gam,formula.gam,predict.gam,
           print.gam,summary.gam,vcov.gam,s)

# ....  load dynamic library .....
#      (native routines are now registered in init.c)
useDynLib(spatstat, .registration=TRUE)

# Do not edit the following.
# It is generated automatically.




# .................................................. 
#  load dynamic library
#      (native routines are now registered in init.c)
# .................................................. 

useDynLib(spatstat, .registration=TRUE)

# .................................................. 
# Automatically-generated list of documented objects 
# .................................................. 
export("acedist.noshow")
export("acedist.show")
export("active.interactions")
export("adaptcoef")
export("adaptive.density")
export("add.texture")
export("addvar")
export("adjust.ratfv")
export("affine")
export("affine.im") 
export("affine.layered")
export("affine.linim")
export("affine.linnet") 
export("affine.lpp") 
export("affine.owin") 
export("affine.ppp") 
export("affine.psp")
export("affine.tess") 
export("affinexy")
export("affinexypolygon")
export("AIC.dppm")
export("AIC.kppm")
export("AIC.mppm")
export("AIC.ppm")
export("allElementsIdentical")
export("allstats")
export("alltypes")
export("ang2rad")
export("angles.psp")
export("anova.lppm")
export("anova.mppm")
export("anova.ppm")
export("anova.slrm")
export("anycrossing.psp")
export("anyDuplicated.ppp")
export("anyDuplicated.ppx")
export("anylapply")
export("[<-.anylist")
export("[.anylist")
export("anylist")
export("anyNA.im")
export("anyNA.sparse3Darray")
export("aperm.sparse3Darray")
export("append.psp")
export("ApplyConnected")
export("applynbd")
export("applyPolyclipArgs")
export("applySparseEntries")
export("apply.ssf")
export("applytolayers")
export("area")
export("area.default")
export("areadelta2")       
export("areaGain")
export("areaGain.diri")       
export("areaGain.grid")       
export("AreaInter")
export("areaLoss")
export("areaLoss.diri")       
export("areaLoss.grid")
export("areaLoss.poly")
export("area.owin")
export("as.anylist")
export("as.array.im")
export("as.array.sparse3Darray")
export("as.box3")
export("as.boxx")
export("as.breakpts")
export("as.character.unitname")
export("as.data.frame.bw.optim")
export("as.data.frame.envelope")
export("as.data.frame.fv")
export("as.data.frame.hyperframe")
export("as.data.frame.im")
export("as.data.frame.linfun")
export("as.data.frame.linim")
export("as.data.frame.owin")
export("as.data.frame.ppp")
export("as.data.frame.ppx")
export("as.data.frame.psp")
export("as.data.frame.tess")
export("as.double.im")
export("as.function.fv")
export("as.function.im")
export("as.function.leverage.ppm")
export("as.function.linfun")
export("as.function.owin")
export("as.function.rhohat")
export("as.function.ssf")
export("as.function.tess")
export("as.fv")
export("as.fv.bw.optim")
export("as.fv.data.frame")
export("as.fv.dppm")
export("as.fv.fasp")
export("as.fv.fv")
export("as.fv.kppm")
export("as.fv.matrix")
export("as.fv.minconfit")
export("as.hyperframe")
export("as.hyperframe.anylist")
export("as.hyperframe.data.frame")
export("as.hyperframe.default")
export("as.hyperframe.hyperframe")
export("as.hyperframe.listof")
export("as.hyperframe.ppx")
export("as.im")
export("as.im.data.frame")
export("as.im.default")
export("as.im.distfun")
export("as.im.function")
export("as.im.funxy")
export("as.im.im")
export("as.im.leverage.ppm")
export("as.im.linim")
export("as.imlist")
export("as.im.matrix")
export("as.im.nnfun")
export("as.im.owin")
export("as.im.ppp")
export("as.im.scan.test")
export("as.im.Smoothfun")
export("as.im.ssf")
export("as.im.tess")
export("as.interact")
export("as.interact.fii")
export("as.interact.interact")
export("as.interact.ppm")
export("as.layered")
export("as.layered.default")
export("as.layered.listof")
export("as.layered.msr")
export("as.layered.ppp")
export("as.layered.solist")
export("as.layered.splitppp")
export("as.linfun")
export("as.linfun.linfun")
export("as.linfun.linim")
export("as.linfun.lintess")
export("as.linim")
export("as.linim.default")
export("as.linim.linfun")
export("as.linim.linim")
export("as.linnet")
export("as.linnet.linfun")
export("as.linnet.linim")
export("as.linnet.linnet")
export("as.linnet.lintess")
export("as.linnet.lpp")
export("as.linnet.lppm")
export("as.linnet.psp")
export("as.list.hyperframe")
export("as.listof")
export("as.lpp")
export("as.mask")
export("as.mask.psp")
export("as.matrix.im")
export("as.matrix.owin")
export("as.matrix.ppx")
export("as.owin")
export("as.owin.boxx")
export("as.owin.data.frame")
export("as.owin.default")
export("as.owin.distfun")
export("as.owin.dppm")
export("as.owin.funxy")
export("as.owin.im")
export("as.owin.influence.ppm")
export("as.owin.kppm")
export("as.owin.layered")
export("as.owin.leverage.ppm")
export("as.owin.linfun")
export("as.owin.linnet")
export("as.owin.lintess")
export("as.owin.lpp")
export("as.owin.lppm")
export("as.owin.msr")
export("as.owin.nnfun")
export("as.owin.owin")
export("as.owin.ppm")
export("as.owin.ppp")
export("as.owin.psp")
export("as.owin.quad")
export("as.owin.quadratcount")
export("as.owin.quadrattest")
export("as.owin.rmhmodel")
export("as.owin.tess")
export("as.polygonal")
export("as.ppm")
export("as.ppm.dppm")
export("as.ppm.kppm")
export("as.ppm.lppm")
export("as.ppm.ppm")
export("as.ppm.profilepl")
export("as.ppm.rppm")
export("as.ppp")
export("as.ppp.data.frame")
export("as.ppp.default")
export("as.ppp.influence.ppm")
export("as.ppplist")
export("as.ppp.lpp")
export("as.ppp.matrix")
export("as.ppp.ppp")
export("as.ppp.psp")
export("as.ppp.quad")
export("as.ppp.ssf")
export("as.psp")
export("as.psp.data.frame")
export("as.psp.default")
export("as.psp.linnet")
export("as.psp.lpp")
export("as.psp.matrix")
export("as.psp.owin")
export("as.psp.psp")
export("as.rectangle")
export("assemble.plot.objects")       
export("as.solist")
export("as.sparse3Darray")
export("as.tess")
export("as.tess.im")
export("as.tess.list")
export("as.tess.owin")
export("as.tess.quadratcount")
export("as.tess.quadrattest")
export("as.tess.tess")
export("as.unitname")
export("AsymmDistance.psp")
export("auc")
export("auc.kppm")
export("auc.lpp")
export("auc.lppm")
export("auc.ppm")
export("auc.ppp")
export("augment.msr")
export("BadGey")
export("BartCalc")
export("bbEngine")
export("bc")
export("bc.ppm")
export("bdist.pixels")
export("bdist.points")
export("bdist.tiles")
export("bdry.mask")
export("beachcolourmap")
export("beachcolours")
export("beginner")
export("begins")
export("berman.test")
export("bermantest")
export("bermantestEngine")
export("berman.test.lpp")
export("bermantest.lpp")
export("berman.test.lppm")
export("bermantest.lppm")
export("berman.test.ppm")
export("bermantest.ppm")
export("berman.test.ppp")
export("bermantest.ppp")
export("bilinearform")
export("bind.fv")
export("bind.ratfv")
export("bind.sparse3Darray")
export("bits.test")
export("blankcoefnames")
export("blur")
export("border")
export("bounding.box")
export("boundingbox")
export("bounding.box3")
export("boundingbox.default")
export("boundingbox.im")
export("boundingbox.linnet")
export("boundingbox.lpp")
export("boundingbox.owin")
export("boundingbox.ppp")
export("boundingbox.psp")
export("boundingbox.solist")
export("bounding.box.xy")
export("boundingcentre")
export("boundingcentre.owin")
export("boundingcentre.ppp")
export("boundingcircle")
export("boundingcircle.owin")
export("boundingcircle.ppp")
export("boundingradius")
export("boundingradius.linnet")
export("boundingradius.owin")
export("boundingradius.ppp")
export("box3")
export("boxx")
export("branchlabelfun")
export("break.holes")
export("breakpts")
export("breakpts.from.r")
export("bt.frame")
export("bugfixes")
export("bw.diggle")
export("bw.frac")
export("bw.optim")
export("bw.pcf")
export("bw.ppl")
export("bw.relrisk")
export("bw.scott")
export("bw.smoothppp")
export("bw.stoyan")
export("by.im")
export("by.ppp")
export("calc.DR")
export("calc.NNIR")
export("calc.SAVE")
export("calc.SIR")
export("calc.TSE")
export("cannot.update")
export("cartesian")
export("cauchy.estK")
export("cauchy.estpcf")
export("cbind.fv")
export("cbind.hyperframe")
export("CDF")
export("CDF.density")
export("cdf.test")
export("cdf.test.lpp")
export("cdf.test.lppm")
export("cdf.test.mppm")
export("cdf.test.ppm")
export("cdf.test.ppp")
export("cdf.test.slrm")
export("cellmiddles")
export("censtimeCDFest")
export("centroid.owin")
export("change.default.expand")          
export("checkbigmatrix")          
export("checkfields")          
export("check.finespacing")
export("check.hist.lengths")
export("check.mat.mul")
export("checksolve")          
export("check.testfun")
export("chop.tess")
export("circdensity")
export("circticks")
export("circumradius")
export("circumradius.linnet")
export("circumradius.owin")
export("circumradius.ppp")
export("clarkevans")
export("clarkevansCalc")
export("clarkevans.test")
export("clear.simplepanel")
export("clf.test")
export("clickbox")
export("clickdist")
export("clickjoin")
export("clicklpp")
export("clickpoly")
export("clickppp")
export("clip.infline")
export("clippoly.psp")
export("clip.psp")
export("cliprect.psp")
export("closepaircounts")
export("closepairs")
export("closepairs.pp3")
export("closepairs.ppp")
export("closethresh")
export("closetriples")
export("closing")
export("closing.owin")
export("closing.ppp")
export("closing.psp")
export("clusterfield")
export("clusterfield.character")
export("clusterfield.function")
export("clusterfield.kppm")
export("clusterfit")
export("clusterkernel")
export("clusterkernel.character")
export("clusterkernel.kppm")
export("clusterradius")
export("clusterradius.character")
export("clusterradius.kppm")
export("clusterset")
export("cobble.xy")
export("codetime")
export("coef.dppm")
export("coef.fii")
export("coef.kppm")
export("coef.lppm")
export("coef.mppm")
export("coef.ppm")
export("coef.slrm")
export("coef.summary.fii")
export("coef.summary.kppm")
export("coef.summary.ppm")
export("coef.vblogit") 
export("coerce.marks.numeric")
export("col2hex")
export("col.args.to.grey")
export("collapse.anylist")
export("collapse.fv")
export("colourmap")
export("colouroutputs<-")
export("colouroutputs")
export("commonGrid")
export("commonPolyclipArgs")
export("compareFit")
export("compatible")
export("compatible.fasp")
export("compatible.fv")
export("compatible.im")
export("compatible.rat")
export("compatible.unitname")
export("compileCDF")
export("compileK")
export("compilepcf")
export("complementarycolour")
export("complement.owin")
export("Complex.im")
export("Complex.imlist")
export("Complex.linim")
export("concatxy")
export("Concom")
export("conform.imagelist")
export("conform.ratfv")
export("connected")
export("connected.im")
export("connected.linnet")
export("connected.lpp")
export("connected.owin")
export("connected.pp3")
export("connected.ppp")
export("conspire")
export("contour.funxy")
export("contour.im")
export("contour.imlist")
export("contour.listof")
export("contour.objsurf")
export("contour.ssf")
export("convexhull")
export("convexhull.xy")
export("convexify")
export("convolve.im")
export("coords<-")
export("coords")
export("coords<-.ppp")
export("coords.ppp")
export("coords<-.ppx")
export("coords.ppx")
export("corners")
export("countends")
export("countingweights")
export("covering")
export("CressieReadName")
export("CressieReadStatistic")
export("CressieReadSymbol")
export("crossdist")
export("crossdist.default")
export("crossdist.lpp")
export("crossdist.pp3")
export("crossdist.ppp")
export("crossdist.ppx")
export("crossdist.psp")
export("crossing.linnet")
export("crossing.psp")
export("crosspaircounts")
export("crosspairquad")
export("crosspairs")
export("crosspairs.pp3")
export("crosspairs.ppp")
export("cut.im")
export("cut.lpp")
export("cut.ppp")
export("CVforPCF")
export("damaged.ppm")
export("datagen.rpoisppOnLines")
export("datagen.runifpointOnLines")
export("datagen.runifpoisppOnLines")
export("data.mppm")
export("data.ppm")
export("dclf.progress")
export("dclf.sigtrace")
export("dclf.test")
export("default.clipwindow")
export("default.dummy")
export("default.expand")
export("default.linnet.tolerance")
export("default.ntile")
export("default.n.tiling")
export("default.rmhcontrol")
export("delaunay")
export("delaunay.distance")
export("delaunayDistance")
export("delaunay.network")
export("delaunayNetwork")
export("deletebranch")
export("deletebranch.linnet")
export("deletebranch.lpp")
export("deltametric")
export("deltasuffstat")
export("densitycrossEngine")
export("density.linnet")
export("density.lpp")
export("densitypointsEngine")
export("density.ppp")
export("density.ppplist")
export("density.psp")
export("density.splitppp")
export("density.splitppx")
export("deriv.fv")
export("detpointprocfamilyfun")
export("deviance.lppm")
export("deviance.ppm")
export("Deviation")
export("dfbetas.ppm")
export("dflt.redraw")
export("dg.envelope")
export("dg.progress")
export("dg.sigtrace")
export("dg.test")
export("diagnose.ppm")
export("diagnose.ppm.engine")
export("[.diagramobj")
export("diagramobj")
export("diameter")
export("diameter.box3")
export("diameter.boxx")
export("diameter.linnet")
export("diameter.owin")
export("digestCovariates")
export("DiggleGatesStibbard")
export("DiggleGratton")
export("digital.volume")
export("dilated.areas")
export("dilate.owin")
export("dilation")
export("dilationAny")
export("dilation.owin")
export("dilation.ppp")
export("dilation.psp")
export("dim.detpointprocfamily")
export("dim.fasp")               
export("dimhat")
export("dim.hyperframe")               
export("dim.im")               
export("dim.msr")
export("dimnames<-.fasp")
export("dimnames.fasp")               
export("dimnames.msr")
export("dimnames<-.sparse3Darray")
export("dimnames.sparse3Darray")
export("dim.owin")
export("dim<-.sparse3Darray")
export("dim.sparse3Darray")
export("dirichlet")
export("dirichletAreas")
export("dirichlet.edges")
export("dirichletEdges")
export("dirichlet.network")
export("dirichletNetwork")
export("dirichlet.vertices")
export("dirichletVertices")
export("dirichlet.weights")
export("dirichletWeights")
export("disc")
export("discpartarea")
export("discretise")
export("discs")
export("dist2dpath")
export("distcdf")
export("distfun")
export("distfun.lpp")
export("distfun.owin")
export("distfun.ppp")
export("distfun.psp")
export("distmap")
export("distmap.owin")
export("distmap.ppp")
export("distmap.psp")
export("distributecbind")
export("divide.linnet")
export("dkernel")
export("dknn")
export("dmixpois")
export("do.as.im")
export("do.call.plotfun")
export("do.istat")
export("domain")
export("domain.distfun")
export("domain.dppm")
export("domain.funxy")
export("domain.im")
export("domain.im")
export("domain.influence.ppm")
export("domain.kppm")
export("domain.layered")
export("domain.leverage.ppm")
export("domain.linfun")
export("domain.lintess")
export("domain.lpp")
export("domain.lpp")
export("domain.lppm")
export("domain.msr")
export("domain.nnfun")
export("domain.pp3")
export("domain.ppm")
export("domain.ppp")
export("domain.ppx")
export("domain.psp")
export("domain.quad")
export("domain.quadratcount")
export("domain.quadrattest")
export("domain.rmhmodel")
export("domain.tess")
export("doMultiStraussHard")
export("dppapproxkernel")
export("dppapproxpcf")
export("dppBessel")
export("dppCauchy")
export("dppeigen")
export("dppGauss")
export("dppkernel")
export("dppm")
export("dppMatern")
export("dppmFixAlgorithm")
export("dppmFixIntensity")
export("dppparbounds")
export("dppPowerExp")
export("dppspecden")
export("dppspecdenrange")
export("dummify")
export("dummy.ppm")
export("duplicated.ppp")
export("duplicated.ppx")
export("edge.Ripley")
export("edges")
export("edges2triangles")
export("edges2vees")
export("edge.Trans")
export("edit.hyperframe")
export("edit.im")
export("edit.ppp")
export("edit.psp")
export("eem")
export("effectfun")
export("ellipse")
export("Emark")
export("emend")
export("emend.lppm")
export("emend.ppm")
export("emptywindow")
export("endpoints.psp")
export("EntriesToSparse")
export("envelope")
export("envelopeArray")
export("envelopeEngine")
export("envelope.envelope")
export("envelope.hasenvelope")
export("envelope.kppm")
export("envelope.lpp")
export("envelope.lppm")
export("envelope.matrix")
export("envelope.pp3")
export("envelope.ppm")
export("envelope.ppp")
export("envelopeProgressData")
export("envelopeTest")
export("equalpairs")          
export("equalpairs.quad")          
export("equalsfun.quad")          
export("equals.quad")          
export("eroded.areas")
export("eroded.volumes")
export("eroded.volumes.box3")
export("eroded.volumes.boxx")
export("erodemask")
export("erode.owin")
export("erosion")
export("erosionAny")
export("erosion.owin")
export("erosion.ppp")
export("erosion.psp")
export("evalCovar")
export("evalCovariate")
export("evalCovar.lppm")
export("evalCovar.ppm")
export("eval.fasp")
export("eval.fv")
export("eval.hyper")
export("eval.im")
export("evalInteraction")
export("evalInterEngine")
export("eval.linim")
export("evalPairPotential")
export("evalSparse3Dentrywise")
export("evaluate2Dkernel")
export("even.breaks.owin")
export("ewcdf")
export("exactdt")              
export("exactMPLEstrauss")
export("exactPdt")
export("existsSpatstatVariable")
export("expand.owin")
export("expandSparse")
export("expandSpecialLists")
export("expandwinPerfect")
export("ExpSmoothLog")
export("extractAIC.dppm")
export("extractAIC.kppm")
export("extractAIC.lppm")
export("extractAIC.mppm")
export("extractAIC.ppm")
export("extractAIC.slrm")
export("extractAtomicQtests")
export("extractbranch")
export("extractbranch.linnet")
export("extractbranch.lpp")
export("f3Cengine")
export("f3engine")
export("F3est")
export("fakemaintitle")
export("family.vblogit") 
export("fardist")
export("fardist.owin")
export("fardist.ppp")
export("[.fasp")
export("fasp")
export("FDMKERNEL")
export("Fest")
export("fft2D")
export("fftwAvailable")
export("Fhazard")
export("fii")
export("Fiksel")
export("fill.coefs")
export("fillNA")
export("findbestlegendpos")
export("findcbind")
export("findCovariate")
export("Finhom")
export("fitin")
export("fitin.ppm")
export("fitin.profilepl")
export("fitted.dppm")
export("fitted.kppm")
export("fitted.lppm")
export("fitted.mppm")
export("fitted.ppm")
export("fitted.rppm")
export("fitted.slrm")
export("fixef.mppm")
export("flatfname")
export("flipxy")
export("flipxy.im")
export("flipxy.infline")
export("flipxy.layered")
export("flipxy.owin")
export("flipxypolygon")
export("flipxy.ppp")
export("flipxy.psp")
export("FmultiInhom")
export("foo")
export("forbid.logi")
export("FormatFaspFormulae")
export("format.numberwithunit")
export("formula<-")
export("formula.dppm")
export("formula<-.fv")
export("formula.fv")
export("formula.kppm")
export("formula.lppm")
export("formula.ppm")
export("formula.slrm")
export("fourierbasis")
export("fourierbasisraw")
export("Frame<-")
export("Frame")
export("framebottomleft")
export("Frame<-.default")
export("Frame.default")
export("Frame<-.im")
export("Frame<-.owin")
export("Frame<-.ppp")
export("fryplot")
export("frypoints")
export("funxy")
export("[<-.fv")
export("[.fv")
export("$<-.fv")
export("fv")
export("fvexprmap")
export("fvlabelmap")
export("fvlabels<-")
export("fvlabels")
export("fvlegend")
export("fvnames<-")
export("fvnames")
export("g3Cengine")
export("g3engine")
export("G3est")
export("gammabreaks")
export("gauss.hermite")
export("Gcom")
export("Gcross")
export("Gdot")
export("Gest")
export("getCall.mppm")
export("getdataname")
export("getfields")
export("getglmdata")
export("getglmfit")
export("getglmsubset")
export("getlambda.lpp")
export("getlastshift")
export("getppmdatasubset")
export("getppmOriginalCovariates")
export("getRandomFieldsModelGen")
export("getSpatstatVariable")
export("getSumFun")
export("Geyer")
export("geyercounts")
export("geyerdelta2")
export("Gfox")
export("Ginhom")
export("GLMpredict")
export("Gmulti")
export("GmultiInhom")
export("good.correction.K")
export("Gres")
export("grid1index")
export("gridcenters")
export("gridcentres")
export("gridindex")            
export("gridweights")
export("grokIndexVector")
export("grow.box3")
export("grow.boxx")
export("grow.mask")
export("grow.rectangle")
export("grow.simplepanel")
export("hackglmmPQL")
export("Halton")
export("Hammersley")
export("handle.r.b.args")
export("handle.rshift.args")
export("Hardcore")
export("harmonic")
export("harmonise")
export("harmonise.fv")
export("harmonise.im")
export("harmonise.msr")
export("harmonise.owin")
export("harmonise.unitname")
export("harmonize")
export("harmonize.fv")
export("harmonize.im")
export("harmonize.owin")
export("harmonize.unitname")
export("has.close")
export("has.close.default")
export("has.close.pp3")
export("has.close.ppp")
export("hasenvelope")
export("has.offset")
export("has.offset.term")
export("head.hyperframe")
export("head.ppp")
export("head.ppx")
export("head.psp")
export("head.tess")
export("HermiteCoefs")
export("Hest")
export("hexagon")
export("hexgrid")
export("hextess")
export("hierarchicalordering")
export("HierHard")
export("hiermat")
export("hierpair.family")
export("HierStrauss")
export("HierStraussHard")
export("hist.funxy")
export("hist.im")
export("ho.engine")
export("hopskel")
export("hopskel.test")
export("hsvim")
export("hsvNA")
export("Hybrid")
export("hybrid.family")
export("[<-.hyperframe")
export("[.hyperframe")
export("$<-.hyperframe")
export("$.hyperframe")
export("hyperframe")
export("IdenticalRows")
export("identify.lpp")
export("identify.ppp")
export("identify.psp")
export("idorempty")
export("idw")
export("Iest")
export("illegal.iformula")
export("[<-.im")
export("[.im")
export("im")
export("image.im")
export("image.imlist")
export("image.listof")
export("image.objsurf")
export("image.ssf")
export("im.apply")
export("imcov")
export("implemented.for.K")
export("impliedcoefficients")
export("impliedpresence")
export("improve.kppm")
export("incircle")
export("increment.fv")
export("infline")
export("[.influence.ppm")
export("influence.ppm")
export("inforder.family")
export("inpoint")
export("inradius")
export("insertVertices")
export("inside3Darray")
export("inside.boxx")
export("inside.owin")
export("instantiate.interact")
export("integral")
export("integral.im")
export("integral.linfun")
export("integral.linim")
export("integral.msr")
export("integral.ssf")
export("intensity")
export("intensity.detpointprocfamily")
export("intensity.dppm")
export("intensity.lpp")
export("intensity.ppm")
export("intensity.ppp")
export("intensity.ppx")
export("intensity.psp")
export("intensity.quadratcount")
export("intensity.splitppp")
export("interactionfamilyname")
export("intermaker")
export("interp.colourmap")
export("interp.colours")
export("interp.im")
export("intersect.owin")
export("intersect.tess")
export("intX.owin")     
export("intX.xypolygon")     
export("intY.owin")     
export("intY.xypolygon")
export("invokeColourmapRule")
export("invoke.symbolmap")
export("iplot")
export("iplot.default")
export("iplot.layered")
export("iplot.linnet")
export("iplot.lpp")
export("iplot.ppp")
export("ippm")
export("is.atomicQtest")
export("is.cadlag")
export("is.col.argname")
export("is.colour")
export("is.connected")
export("is.connected.default")
export("is.connected.linnet")
export("is.connected.ppp")
export("is.convex")
export("is.data")
export("is.dppm")
export("is.empty")
export("is.empty.default")
export("is.empty.owin")
export("is.empty.ppp")
export("is.empty.psp")
export("is.expandable")
export("is.expandable.ppm")
export("is.expandable.rmhmodel")
export("is.fv")
export("is.grey")
export("is.hybrid")
export("is.hybrid.interact")
export("is.hybrid.ppm")
export("is.hyperframe")
export("is.im")
export("is.infline")
export("is.interact")
export("is.kppm")
export("is.lpp")
export("is.lppm")
export("is.marked")
export("is.marked.default")    
export("is.marked.lppm")
export("is.marked.msr")    
export("is.marked.ppm")
export("is.marked.ppp")
export("is.marked.psp")    
export("is.marked.quad")
export("is.mask")
export("is.mppm")
export("is.multitype")
export("is.multitype.default")    
export("is.multitype.lpp")
export("is.multitype.lppm")
export("is.multitype.msr")    
export("is.multitype.ppm")
export("is.multitype.ppp")
export("is.multitype.quad")    
export("is.owin")
export("is.poisson")
export("is.poisson.interact")
export("is.poisson.kppm")
export("is.poisson.lppm")
export("is.poisson.mppm")
export("is.poisson.ppm")
export("is.poisson.rmhmodel")
export("is.poisson.slrm")
export("is.polygonal")
export("is.pp3")
export("is.ppm")
export("is.ppp")
export("is.ppx")
export("is.psp")
export("is.rectangle")
export("isRelevantZero")
export("is.scov")
export("is.slrm")
export("is.sob")
export("is.stationary")
export("is.stationary.detpointprocfamily")
export("is.stationary.dppm")
export("is.stationary.kppm")
export("is.stationary.lppm")
export("is.stationary.ppm")
export("is.stationary.rmhmodel")
export("is.stationary.slrm")
export("is.subset.owin")
export("istat")
export("is.tess")
export("is.vanilla")
export("Jcross")
export("Jdot")
export("Jest")
export("Jfox")
export("Jinhom")
export("Jmulti")
export("k3engine")
export("K3est")
export("kaplan.meier")
export("Kborder.engine")
export("Kcom")
export("Kcross")
export("Kcross.inhom")
export("Kdot")
export("Kdot.inhom")
export("kernel.factor")
export("kernel.moment")
export("kernel.squint")
export("Kest")
export("Kest.fft")
export("killinteraction")
export("Kinhom")
export("Kmark")
export("Kmeasure")
export("Kmodel")
export("Kmodel.detpointprocfamily")
export("Kmodel.dppm")
export("Kmodel.kppm")
export("Kmodel.ppm")
export("km.rs")
export("km.rs.opt")
export("Kmulti")
export("Kmulti.inhom")
export("Knone.engine")
export("Kount")
export("Kpcf.kppm")               
export("kppm")
export("kppmComLik")
export("kppm.formula")
export("kppmMinCon")
export("kppmPalmLik")
export("kppm.ppp")
export("kppm.quad")
export("kraever")
export("kraeverRandomFields")
export("Krect.engine")
export("Kres")
export("Kscaled")
export("Ksector")
export("ksmooth.ppp")
export("kstest")
export("kstest.lpp")
export("kstest.lppm")
export("ks.test.ppm")
export("kstest.ppm")
export("kstest.ppp")
export("kstest.slrm")
export("Kwtsum")               
export("labels.dppm")
export("labels.kppm")
export("labels.ppm")
export("labels.slrm")
export("LambertW")
export("laslett")
export("latest.news")
export("[<-.layered")
export("[.layered")
export("[[<-.layered")
export("layered")
export("layerplotargs<-")
export("layerplotargs")
export("layout.boxes")
export("Lcross")
export("Lcross.inhom")
export("Ldot")
export("Ldot.inhom")
export("ldtEngine")
export("lengths.psp")
export("LennardJones")
export("Lest")
export("levelsAsFactor")
export("levelset")
export("levels<-.im")
export("levels.im")
export("leverage")
export("[.leverage.ppm")
export("leverage.ppm")
export("lgcp.estK")
export("lgcp.estpcf")
export("lineardirichlet")
export("lineardisc")
export("linearK")
export("linearKcross")
export("linearKcross.inhom")
export("linearKdot")
export("linearKdot.inhom")
export("linearKengine")
export("linearKinhom")
export("linearKmulti")
export("linearKmultiEngine")
export("linearKmulti.inhom")
export("linearmarkconnect")
export("linearmarkequal")
export("linearpcf")
export("linearpcfcross")
export("linearpcfcross.inhom")
export("linearpcfdot")
export("linearpcfdot.inhom")
export("linearpcfengine")
export("linearpcfinhom")
export("linearpcfmulti")
export("linearPCFmultiEngine")
export("linearpcfmulti.inhom")
export("linequad")
export("linfun")
export("Linhom")
export("[<-.linim")
export("[.linim")
export("linim")
export("[.linnet")
export("linnet")
export("lintess")
export("[<-.listof")
export("listof")
export("lixellate")
export("local2lpp")
export("localK")
export("localKengine")
export("localKinhom")
export("localL")
export("localLinhom")
export("localpcf")
export("localpcfengine")
export("localpcfinhom")
export("[.localpcfmatrix")
export("localpcfmatrix")
export("logicalIndex")
export("logi.dummy")
export("logi.engine")
export("logLik.dppm")
export("logLik.kppm")
export("logLik.lppm")
export("logLik.mppm")
export("logLik.ppm")
export("logLik.slrm")
export("logLik.vblogit")
export("lohboot")
export("lookup2DkernelInfo")
export("lookup.im")
export("[.lpp")
export("lpp")
export("lppm")
export("lppm.formula")
export("lppm.lpp")
export("Lscaled")
export("lurking")               
export("lut")
export("mad.progress")
export("mad.sigtrace")
export("mad.test")
export("majorminorversion")
export("make.even.breaks")
export("makefvlabel")
export("makeLinnetTolerance")
export("makeunitname")
export("mapSparseEntries")
export("marginSums")
export("markappend")
export("markappendop")
export("markcbind")
export("markconnect")
export("markcorr")
export("markcorrint")
export("markcrosscorr")
export("markformat")
export("markformat.default")
export("markformat.ppp")
export("markformat.ppx")
export("markformat.psp")
export("markmean")
export("markreplicateop")
export("marks<-")           
export("marks")
export("mark.scale.default")
export("marks.default")           
export("marks<-.lpp")
export("markspace.integral")
export("marks<-.ppp")           
export("marks.ppp")           
export("marks<-.ppx")           
export("marks.ppx")           
export("marks<-.psp")
export("marks.psp")
export("marks.quad")           
export("marks<-.ssf")
export("marks.ssf")
export("markstat")
export("marks<-.tess")
export("marks.tess")
export("marksubset")
export("marksubsetop")
export("marktable")
export("markvar")
export("markvario")
export("mask2df")
export("maskLaslett")
export("match2DkernelName")
export("matchingdist")
export("match.kernel")
export("matclust.estK")
export("matclust.estpcf")
export("Math.im")
export("Math.imlist")
export("Math.linim")
export("Math.sparse3Darray")
export("matrixinvsqrt")
export("matrixpower")
export("matrixsqrt")
export("maxflow")
export("max.fv")
export("maxnndist")
export("max.ssf")
export("mctest.progress")
export("mctest.sigtrace")
export("mctestSigtraceEngine")
export("mean.im")
export("mean.linim")
export("meanlistfv")
export("meanX.owin")
export("meanY.owin")
export("measureNegative")
export("measurePositive")
export("measureVariation")
export("median.im")
export("median.linim")
export("mergeLevels")
export("midpoints.psp")
export("mincontrast")
export("min.fv")
export("MinkowskiSum")
export("minnndist")
export("min.ssf")
export("miplot")
export("model.covariates")
export("model.depends")
export("model.frame.dppm")
export("modelFrameGam")
export("model.frame.kppm")
export("model.frame.lppm")
export("model.frame.ppm")
export("model.images")
export("model.images.dppm")
export("model.images.kppm")
export("model.images.lppm")
export("model.images.ppm")
export("model.images.slrm")
export("model.is.additive")
export("model.matrix.dppm")
export("model.matrix.ippm")
export("model.matrix.kppm")
export("model.matrix.lppm")
export("model.matrix.ppm")
export("model.matrix.slrm")
export("model.se.image")
export("mpl")
export("mpl.engine")
export("mpl.get.covariates")
export("mpl.prepare")
export("mpl.usable")
export("mppm")
export("[.msr")
export("msr")
export("MultiHard")
export("MultiPair.checkmatrix")
export("multiplicity")
export("multiplicity.data.frame")
export("multiplicity.default")
export("multiplicityNumeric")
export("multiplicity.ppp")
export("multiplicity.ppx")
export("multiply.only.finite.entries")
export("MultiStrauss")
export("MultiStraussHard")
export("na.handle.im")
export("names<-.fv")
export("names<-.hyperframe")
export("names.hyperframe")
export("nearest.neighbour")
export("nearest.pixel")
export("nearest.raster.point")
export("nearestsegment")
export("nearest.valid.pixel")
export("nestsplit")
export("newformula")
export("newstyle.coeff.handling")
export("nnclean")
export("nncleanEngine")
export("nnclean.pp3")
export("nnclean.ppp")
export("nncorr")
export("nncross")
export("nncross.default")
export("nncross.lpp")
export("nncross.pp3")
export("nncross.ppp")
export("nndcumfun")
export("nndensity")
export("nndensity.ppp")
export("nndist")
export("nndist.default")
export("nndist.lpp")
export("nndist.pp3")
export("nndist.ppp")
export("nndist.ppx")
export("nndist.psp")
export("nnfromvertex")
export("nnfun")
export("nnfun.lpp")
export("nnfun.ppp")
export("nnfun.psp")
export("nnmap")
export("nnmark")
export("nnmean")
export("nnorient")
export("nnvario")
export("nnwhich")
export("nnwhich.default")
export("nnwhich.lpp")
export("nnwhich.pp3")
export("nnwhich.ppp")
export("nnwhich.ppx")
export("nobjects")
export("nobjects.ppp")
export("nobjects.ppx")
export("nobjects.psp")
export("nobjects.tess")
export("nobs.dppm")
export("nobs.kppm")
export("nobs.lppm")
export("nobs.mppm")
export("nobs.ppm")
export("no.trend.ppm")
export("npfun")
export("npoints")
export("npoints.pp3")
export("npoints.ppp")
export("npoints.ppx")
export("n.quad")
export("nsegments")
export("nsegments.linnet")
export("nsegments.lpp")
export("nsegments.psp")
export("numberwithunit")
export("numeric.columns")
export("nvertices")
export("nvertices.default")
export("nvertices.linnet")
export("nvertices.owin")
export("objsurf")
export("objsurf.dppm")
export("objsurfEngine")
export("objsurf.kppm")
export("objsurf.minconfit")
export("onearrow")
export("onecolumn")
export("opening")
export("opening.owin")
export("opening.ppp")
export("opening.psp")
export("Ops.im")
export("Ops.imlist")
export("Ops.linim")
export("Ops.msr")
export("Ops.sparse3Darray")
export("optimStatus")
export("Ord")
export("ord.family")
export("OrdThresh")
export("outdated.interact")
export("overlap.owin")
export("oversize.quad")    
export("[.owin")
export("owin")
export("owin2polypath")
export("owinpoly2mask")
export("owinpolycheck")
export("padimage")
export("pairdist")
export("pairdist.default")
export("pairdist.lpp")
export("pairdist.pp3")
export("pairdist.ppp")
export("pairdist.ppx")
export("pairdist.psp")
export("pairorient")
export("PairPiece")
export("PairPotentialType")
export("pairsat.family")
export("pairs.im")
export("pairs.linim")
export("pairs.listof")
export("pairs.solist")
export("Pairwise")
export("pairwise.family")
export("paletteindex")
export("paletteindex")
export("panel.contour")
export("panel.histogram")
export("panel.image")
export("parameters")
export("parameters.dppm")
export("parameters.fii")
export("parameters.interact")
export("parameters.kppm")
export("parameters.ppm")
export("parameters.profilepl")
export("param.quad")
export("parbreak")
export("parres")
export("partialModelMatrix")
export("pcf")
export("pcf3engine")
export("pcf3est")
export("pcfcross")
export("pcfcross.inhom")
export("pcfdot")
export("pcfdot.inhom")
export("pcf.fasp")
export("pcf.fv")
export("pcfinhom")
export("pcfmodel")
export("pcfmodel.detpointprocfamily")
export("pcfmodel.dppm")
export("pcfmodel.kppm")
export("pcfmodel.ppm")
export("pcfmodel.zclustermodel")
export("pcfmulti")
export("pcfmulti.inhom")
export("pcf.ppp")
export("PDEdensityLPP")
export("Penttinen")
export("perimeter")
export("periodify")
export("periodify.owin")
export("periodify.ppp")
export("periodify.psp")
export("perspContour")
export("persp.funxy")
export("persp.im")
export("persp.leverage.ppm")
export("perspLines")
export("persp.objsurf")
export("perspPoints")
export("perspSegments")
export("pickoption")
export("pixelcentres")
export("pixellate")
export("pixellate.linnet")
export("pixellate.owin")
export("pixellate.ppp")
export("pixellate.psp")
export("pixelquad")
export("pkernel")
export("pknn")
export("plan.legend.layout")
export("plot3Dpoints")
export("plot.addvar")
export("plot.anylist")
export("plot.barplotdata")
export("plot.bermantest")
export("plot.bw.frac")
export("plot.bw.optim")
export("plot.cdftest")
export("plot.colourmap")
export("plot.diagppm")
export("plot.dppm")
export("plotEachLayer")
export("plot.envelope")
export("ploterodeimage")
export("ploterodewin")
export("plot.fasp")
export("plot.fii")
export("plot.foo")
export("plot.funxy")
export("plot.fv")
export("plot.hyperframe")
export("plot.im")
export("plot.imlist")
export("plot.infline")
export("plot.influence.ppm")
export("plot.kppm")
export("plot.kstest")
export("plot.laslett")
export("plot.layered")
export("plot.leverage.ppm")
export("plot.linfun")
export("plot.linim")
export("plot.linnet")
export("plot.lintess")
export("plot.listof")
export("plot.localpcfmatrix")
export("plot.lpp")
export("plot.lppm")
export("plot.lurk")
export("plot.minconfit")
export("plot.mppm")
export("plot.msr")
export("plot.objsurf")
export("plot.onearrow")
export("plot.owin")
export("plot.parres")
export("plot.plotpairsim")
export("plot.plotppm")
export("plotPolygonBdry")
export("plot.pp3")
export("plot.ppm")
export("plot.ppp")
export("plot.pppmatching")
export("plot.ppx")
export("plot.profilepl")
export("plot.psp")
export("plot.qqppm")
export("plot.quad")
export("plot.quadratcount")
export("plot.quadrattest")
export("plot.rho2hat")
export("plot.rhohat")
export("plot.rppm")
export("plot.scan.test")
export("plot.slrm")
export("plot.solist")
export("plot.spatialcdf")
export("plot.splitppp")
export("plot.ssf")
export("plot.studpermutest")
export("plot.symbolmap")
export("plot.tess")
export("plot.textstring")
export("plot.texturemap")
export("plot.yardstick")
export("pmixpois")
export("pointgrid")
export("pointsAlongNetwork")
export("points.lpp")
export("pointsOnLines")
export("PoisSaddle")
export("PoisSaddleArea")
export("PoisSaddleGeyer")
export("PoisSaddlePairwise")
export("Poisson")
export("polyLaslett")
export("polynom")
export("polytileareaEngine")
export("pool")
export("pool.anylist")
export("pool.envelope")
export("pool.fasp")
export("pool.fv")
export("pool.quadrattest")
export("pool.rat")
export("positiveIndex")
export("[.pp3")
export("pp3")
export("ppllengine")
export("ppm")
export("ppmCovariates")
export("ppm.default")
export("ppmDerivatives")
export("ppm.formula")
export("ppmInfluence")
export("ppmInfluenceEngine")
export("PPMmodelmatrix")
export("ppm.ppp")
export("ppm.quad")
export("[<-.ppp")
export("[.ppp")
export("ppp")
export("pppdist")
export("pppdist.mat")
export("pppdist.prohorov")
export("pppmatching")
export("ppsubset")
export("PPversion")
export("[.ppx")
export("ppx")
export("predict.dppm")
export("predict.kppm")
export("predict.lppm")
export("predict.mppm")
export("predict.ppm")
export("predict.profilepl")
export("predict.rho2hat")
export("predict.rhohat")
export("predict.rppm")
export("predict.slrm")
export("predict.vblogit")
export("predict.zclustermodel")
export("prefixfv")
export("prepareTitle")
export("print.addvar")    
export("print.anylist")    
export("print.autoexec")    
export("print.box3")
export("print.boxx")
export("print.bt.frame")
export("print.bugtable")
export("print.bw.frac")
export("print.bw.optim")
export("print.colourmap")
export("print.detpointprocfamily")
export("print.detpointprocfamilyfun")
export("print.diagppm")
export("print.distfun")
export("print.dppm")
export("print.envelope")
export("print.ewcdf")
export("print.fasp")       
export("print.fii")
export("print.funxy")       
export("print.fv")       
export("print.fvfun")       
export("print.hasenvelope")       
export("print.hierarchicalordering")
export("print.hyperframe")
export("print.im")
export("print.indicfun")       
export("print.infline")
export("print.influence.ppm")       
export("print.interact")       
export("print.intermaker")       
export("print.isf")
export("print.kppm")
export("print.laslett")
export("print.layered")
export("print.leverage.ppm")
export("print.linfun")
export("print.linim")
export("print.linnet")
export("print.lintess")
export("print.localpcfmatrix")
export("print.lpp")
export("print.lppm")
export("print.lut")
export("print.minconfit")
export("print.mppm")
export("print.msr")
export("print.nnfun")
export("print.numberwithunit")
export("print.objsurf")
export("print.onearrow")
export("print.owin")
export("print.parres")
export("print.plotpairsim")
export("print.plotppm")
export("print.pp3")
export("print.ppm")
export("print.ppp")
export("print.pppmatching")
export("print.ppx")
export("print.profilepl")
export("print.psp")
export("print.qqppm")
export("print.quad")
export("print.quadrattest")
export("print.rat")
export("print.rho2hat")
export("print.rhohat")
export("print.rmhcontrol")
export("print.rmhexpand")
export("print.rmhInfoList")
export("print.rmhmodel")
export("print.rmhstart")
export("print.rppm")
export("print.simplepanel")
export("print.slrm")
export("print.Smoothfun")       
export("print.solist")
export("print.sparse3Darray")
export("print.splitppp")
export("print.splitppx")
export("print.ssf")
export("printStatus")
export("print.summary.fii")
export("print.summary.hyperframe")
export("print.summary.im")
export("print.summary.kppm")
export("print.summary.linim")
export("print.summary.linnet")
export("print.summary.lintess")
export("print.summary.listof")
export("print.summary.logiquad")
export("print.summary.lpp")
export("print.summary.lut")
export("print.summary.mppm")
export("print.summary.owin")
export("print.summary.pp3")
export("print.summary.ppm")
export("print.summary.ppp")
export("print.summary.psp")
export("print.summary.quad")
export("print.summary.rmhexpand")
export("print.summary.solist")
export("print.summary.splitppp")
export("print.summary.splitppx")
export("print.summary.unitname")
export("print.symbolmap")       
export("print.tess")
export("print.textstring")
export("print.texturemap")
export("print.timed")
export("print.unitname")
export("print.vblogit")
export("print.yardstick")
export("print.zclustermodel")
export("profilepl")
export("progressreport")
export("project2segment")
export("project2set")
export("project3Dhom")
export("project.ppm")
export("prune.rppm")
export("pseudoR2")
export("pseudoR2.lppm")
export("pseudoR2.ppm")
export("psib")
export("psib.kppm")
export("[.psp")
export("psp")
export("psst")
export("psstA")
export("psstG")
export("putlastshift")
export("putSpatstatVariable")
export("qkernel")
export("qknn")
export("qmixpois")
export("qqplot.ppm")
export("QQversion")
export("[.quad")
export("quad")
export("quadBlockSizes")
export("quadform")
export("quad.mppm")
export("quad.ppm")
export("quadratcount")
export("quadratcount.ppp")
export("quadratcount.splitppp")
export("quadratresample")
export("quadrats")
export("quadrat.test")
export("quadrat.testEngine")
export("quadrat.test.mppm")
export("quadrat.test.ppm")
export("quadrat.test.ppp")
export("quadrat.test.quadratcount")
export("quadrat.test.splitppp")
export("quadscheme")
export("quadscheme.logi")
export("quadscheme.replicated")
export("quadscheme.spatial")
export("quantess")
export("quantess.im")
export("quantess.owin")
export("quantess.ppp")
export("quantile.density")
export("quantile.ewcdf")
export("quantile.im")
export("quantile.linim")
export("rags")
export("ragsAreaInter")
export("ragsMultiHard")
export("RandomFieldsSafe")
export("ranef.mppm")
export("range.fv")
export("range.ssf")
export("rasterfilter")
export("rastersample")
export("raster.x")
export("rasterx.im")
export("rasterx.mask")
export("raster.xy")
export("rasterxy.im")
export("rasterxy.mask")
export("raster.y")
export("rastery.im")
export("rastery.mask")
export("[.rat")
export("rat")
export("ratfv")
export("rbindCompatibleDataFrames")
export("rbind.hyperframe")
export("rCauchy")
export("rcell")
export("rcellnumber")
export("rDGS")
export("rDiggleGratton")
export("rdpp")
export("reach")
export("reach.detpointprocfamily")
export("reach.dppm")
export("reach.fii")
export("reach.interact")
export("reach.ppm")
export("reach.rmhmodel")
export("rebadge.as.crossfun")
export("rebadge.as.dotfun")
export("rebadge.fv")
export("rebound")
export("rebound.im")
export("rebound.owin")
export("rebound.ppp")
export("rebound.psp")
export("recognise.spatstat.type")
export("reconcile.fv")
export("rectquadrat.breaks")
export("rectquadrat.countEngine")
export("redraw.simplepanel")
export("reduced.sample")
export("reduceformula")
export("reflect")
export("reflect.default")
export("reflect.im")
export("reflect.infline")
export("reflect.layered")
export("reflect.tess") 
export("regularpolygon")
export("reheat")
export("reincarnate.interact")
export("RelevantDeviation")
export("RelevantEmpty")
export("RelevantZero")
export("relevel.im")
export("relevel.ppp")
export("relevel.ppx")
export("reload.or.compute")
export("relrisk")
export("relrisk.ppm")
export("relrisk.ppp")
export("rename.fv")
export("repair.image.xycoords")
export("repair.old.factor.image")
export("replacementIndex")
export("representativeRows")
export("requireversion")
export("resampleNetworkDataFrame")
export("rescale")
export("rescale.im")
export("rescale.layered")
export("rescale.linnet")
export("rescale.lpp")
export("rescale.owin")
export("rescale.ppp")
export("rescale.psp")
export("rescale.unitname")
export("rescue.rectangle")
export("reset.spatstat.options")
export("resid1panel")
export("resid1plot")
export("resid4plot")
export("residuals.dppm")
export("residuals.kppm")
export("residuals.mppm")
export("residuals.ppm")
export("resolve.2D.kernel")
export("resolveEinfo")
export("resolve.vargamma.shape")
export("restrict.mask")
export("reversePolyclipArgs")
export("rex")
export("rGaussPoisson")
export("rgb2hex")
export("rgb2hsva")
export("rgbim")
export("rgbNA")
export("rHardcore")
export("rho2hat")
export("rhohat")
export("rhohatCalc")
export("rhohatEngine")
export("rhohat.lpp")
export("rhohat.lppm")
export("rhohat.ppm")
export("rhohat.ppp")
export("rhohat.quad")
export("ripras")
export("rjitter")
export("rkernel")
export("rknn")
export("rlabel")
export("rLGCP")
export("rlinegrid")
export("rlpp")
export("rMatClust")
export("rMaternI")
export("rMaternII")
export("rMaternInhibition")
export("rmax.Rigid")
export("rmax.Ripley")
export("rmax.rule")
export("rmax.Trans")
export("rmh")
export("rmhcontrol")
export("rmhcontrol.default")
export("rmhcontrol.list")
export("rmhcontrol.rmhcontrol")
export("rmh.default")
export("rmhEngine")
export("rmhexpand")
export("RmhExpandRule")
export("rmhmodel")
export("rmhmodel.default")
export("rmhmodel.list")
export("rmhmodel.ppm")
export("rmhmodel.rmhmodel")
export("rmh.ppm")
export("rmhResolveControl")
export("rmhResolveExpansion")
export("rmhResolveTypes")
export("rmhsnoop")
export("rmhSnoopEnv")
export("rmhstart")
export("rmhstart.default")
export("rmhstart.list")
export("rmhstart.rmhstart")
export("rmixpois")
export("rMosaicField")
export("rMosaicSet")
export("rmpoint")
export("rmpoint.I.allim")
export("rmpoispp")
export("rNeymanScott")
export("rnoise")
export("roc")
export("rocData")
export("roc.kppm")
export("roc.lpp")
export("roc.lppm")
export("rocModel")
export("roc.ppm")
export("roc.ppp")
export("rose")
export("roseContinuous")
export("rose.default")
export("rose.density")
export("rose.fv")
export("rose.histogram")
export("rotate")
export("rotate.im")
export("rotate.infline")
export("rotate.layered")
export("rotate.linnet")
export("rotate.lpp")
export("rotate.owin")
export("rotate.ppp")
export("rotate.psp")
export("rotate.tess") 
export("rotmean")
export("rotxy")
export("rotxypolygon")
export("rounding")
export("rounding.default")
export("rounding.pp3")
export("rounding.ppp")
export("rounding.ppx")
export("round.pp3")
export("round.ppp")
export("round.ppx")
export("row.names<-.hyperframe")
export("row.names.hyperframe")
export("rPenttinen")
export("rpoint")
export("rpoint.multi")
export("rpoisline")
export("rpoislinetess")
export("rpoislpp")
export("rpoispp")
export("rpoispp3")
export("rpoisppOnLines")
export("rpoisppx")
export("rPoissonCluster")
export("rppm")
export("rQuasi")
export("rshift")
export("rshift.ppp")
export("rshift.psp")
export("rshift.splitppp")
export("rSSI")
export("rstrat")
export("rStrauss")
export("rStraussHard")
export("rsyst")
export("rtemper")
export("rthin")
export("rThomas")
export("rtoro")
export("ruletextline")
export("runifdisc")
export("runiflpp")
export("runifpoint")
export("runifpoint3")
export("runifpointOnLines")
export("runifpointx")
export("runifpoispp")          
export("runifpoisppOnLines")          
export("runifrect")
export("run.simplepanel")
export("rVarGamma")
export("safedeldir")
export("safelookup")
export("samecolour")
export("SatPiece")
export("Saturated")
export("scalardilate")
export("scalardilate.breakpts")
export("scalardilate.default")
export("scalardilate.diagramobj")
export("scalardilate.im")
export("scalardilate.layered")
export("scalardilate.linim")
export("scalardilate.linnet")
export("scalardilate.lpp")
export("scalardilate.msr")
export("scalardilate.owin")
export("scalardilate.ppp")
export("scalardilate.psp")
export("scalardilate.tess") 
export("scaletointerval")
export("scaletointerval.default")
export("scaletointerval.im")
export("scanBinomLRTS")
export("scanLRTS")
export("scanmeasure")
export("scanmeasure.im")
export("scanmeasure.ppp")
export("scanPoisLRTS")
export("scanpp")
export("scan.test")
export("sdr")
export("sdrPredict")
export("second.moment.calc")
export("second.moment.engine")
export("segregation.test")
export("segregation.test.ppp")
export("selfcrossing.psp")
export("selfcut.psp")
export("sessionLibs")
export("setcov")
export("setmarks")
export("setminus.owin")
export("sewpcf")
export("sewsmod")
export("sharpen")
export("sharpen.ppp")
export("shift")
export("shift.diagramobj")              
export("shift.im")
export("shift.infline")
export("shift.influence.ppm")              
export("shift.layered")
export("shift.leverage.ppm")              
export("shift.linim")
export("shift.linnet")
export("shift.lpp") 
export("shift.msr")              
export("shift.owin")
export("shift.ppp")
export("shift.psp")
export("shift.quadratcount")              
export("shift.quadrattest")              
export("shift.tess") 
export("shiftxy")              
export("shiftxypolygon")              
export("shortside")
export("shortside.box3")
export("shortside.boxx")
export("shortside.owin")
export("sidelengths")
export("sidelengths.box3")
export("sidelengths.boxx")
export("sidelengths.owin")
export("signalStatus")
export("simplepanel")
export("simplify.owin")
export("simulate.detpointprocfamily")
export("simulate.dppm")
export("simulate.kppm")
export("simulate.lppm")
export("simulate.mppm")
export("simulate.ppm")
export("simulate.profilepl")
export("simulate.rhohat")
export("simulate.slrm")
export("simulrecipe")              
export("slrAssemblePixelData")
export("slrm")
export("slr.prepare")
export("Smooth")
export("smoothcrossEngine")              
export("Smoothfun")
export("Smoothfun.ppp")
export("smooth.fv")
export("Smooth.fv")
export("Smooth.im")
export("smooth.msr")
export("Smooth.msr")
export("smoothpointsEngine")
export("smooth.ppp")
export("Smooth.ppp")
export("Smooth.solist")
export("Smooth.ssf")
export("smudge")
export("Softcore")
export("solapply")
export("[<-.solist")
export("[.solist")
export("solist")
export("solutionset")
export("sortalongsegment")
export("sort.im")
export("[<-.sparse3Darray")
export("[.sparse3Darray")
export("sparse3Darray")
export("SparseEntries")
export("SparseIndices")
export("sparseVectorCumul")
export("spatdim")
export("spatialcdf")
export("spatialCDFframe")
export("spatialCDFtest")
export("spatstatClusterModelInfo")
export("spatstatDiagnostic")
export("spatstatDPPModelInfo")
export("spatstat.options")
export("spatstatRmhInfo")
export("spatstat.xy.coords")
export("sp.foundclass")
export("sp.foundclasses")
export("sphere.volume")
export("splitHybridInteraction")
export("split<-.hyperframe")
export("split.hyperframe")
export("split.im")
export("split.msr")
export("[<-.splitppp")
export("[.splitppp")
export("split<-.ppp")
export("split.ppp")
export("[<-.splitppx")
export("[.splitppx")
export("split.ppx")
export("spokes")
export("square")
export("[.ssf")
export("ssf")
export("stieltjes")
export("stienen")
export("stienenSet")
export("store.versionstring.spatstat")
export("stratrand")
export("Strauss")
export("strausscounts")
export("StraussHard")
export("str.hyperframe")
export("studpermu.test")
export("subfits")
export("subfits.new")
export("subfits.old")
export("subset.hyperframe")
export("subset.lpp")
export("subset.pp3")
export("subset.ppp")
export("subset.ppx")
export("subspaceDistance")
export("suffloc")
export("suffstat")
export("suffstat.generic")
export("suffstat.poisson")
export("summarise.trend")
export("summary.anylist")
export("summary.envelope")
export("summary.fii")
export("summary.funxy")
export("summary.hyperframe")
export("summary.im")
export("Summary.im")
export("Summary.imlist")
export("summary.kppm")
export("summary.linfun")
export("summary.linim")
export("Summary.linim")
export("summary.linnet")
export("summary.lintess")
export("summary.listof")
export("summary.logiquad")
export("summary.lpp")
export("summary.lppm")
export("summary.lut")
export("summary.mppm")
export("summary.owin")
export("summary.pp3")
export("summary.ppm")
export("summary.ppp")
export("summary.pppmatching")
export("summary.ppx")
export("summary.profilepl")
export("summary.psp")
export("summary.quad")
export("summary.rmhexpand")
export("summary.solist")
export("Summary.sparse3Darray")
export("summary.splitppp")
export("summary.splitppx")
export("summary.unitname")
export("summary.vblogit")
export("sumouter")
export("sumsymouter")
export("sumsymouterSparse")
export("superimpose")
export("superimpose.default")
export("superimpose.lpp")
export("superimposeMarks")
export("superimpose.ppp")
export("superimpose.ppplist")
export("superimpose.psp")
export("superimposePSP")
export("superimpose.splitppp")
export("symbolmap")
export("symbolmaptype")
export("tail.hyperframe")
export("tail.ppp")
export("tail.ppx")
export("tail.psp")
export("tail.tess")
export("tenseur")
export("tensor1x1")
export("terms.dppm")
export("terms.kppm")
export("terms.lppm")
export("terms.mppm")
export("terms.ppm")
export("terms.slrm")
export("[<-.tess")
export("[.tess")
export("tess")
export("test.crossing.psp")
export("test.selfcrossing.psp")
export("text.lpp")
export("text.ppp")
export("text.psp")
export("textstring")
export("texturemap")
export("textureplot")
export("thinjump")
export("thinNetwork")
export("thomas.estK")
export("thomas.estpcf")
export("tile.areas")
export("tilecentroids")        
export("tileindex")
export("tile.lengths")
export("tilenames<-")
export("tilenames")
export("tiles")
export("tiles.empty")
export("timed")
export("timeTaken")
export("to.grey")
export("to.opaque")
export("to.saturated")
export("totalVariation")
export("to.transparent")
export("transect.im")
export("transmat")
export("treebranchlabels")
export("treeprune")
export("trianglediameters")
export("triangulate.owin")
export("trim.mask")        
export("trim.rectangle")
export("triplet.family")
export("Triplets")
export("Tstat")
export("tweak.coefs")
export("tweak.colourmap")
export("tweak.fv.entry")
export("tweak.ratfv.entry")
export("twostage.test")
export("unionOfSparseIndices")
export("union.owin")
export("union.quad")
export("unique.ppp")
export("unique.ppx")
export("unitname<-")
export("unitname")
export("unitname<-.box3")
export("unitname.box3")
export("unitname<-.boxx")
export("unitname.boxx")
export("unitname<-.default")
export("unitname.default")
export("unitname<-.dppm")
export("unitname.dppm")
export("unitname<-.im")
export("unitname.im")
export("unitname<-.kppm")
export("unitname.kppm")
export("unitname<-.linnet")
export("unitname.linnet")
export("unitname<-.lpp")
export("unitname.lpp")
export("unitname<-.minconfit")
export("unitname.minconfit")
export("unitname<-.owin")
export("unitname.owin")
export("unitname<-.pp3")
export("unitname.pp3")
export("unitname<-.ppm")
export("unitname.ppm")
export("unitname<-.ppp")
export("unitname.ppp")
export("unitname<-.ppx")
export("unitname.ppx")
export("unitname<-.psp")
export("unitname.psp")
export("unitname<-.quad")
export("unitname.quad")
export("unitname<-.slrm")
export("unitname.slrm")
export("unitname<-.tess")
export("unitname.tess")
export("unit.square")
export("unmark")
export("unmark.lpp")
export("unmark.ppp")
export("unmark.ppx")
export("unmark.psp")
export("unmark.splitppp")
export("unmark.ssf")
export("unmark.tess")
export("unnormdensity")
export("unstackFilter")
export("unstack.layered")
export("unstack.lpp")
export("unstack.msr")
export("unstack.ppp")
export("unstack.psp")
export("unstack.solist")
export("update.detpointprocfamily")
export("update.im")
export("update.interact")
export("update.ippm")
export("update.kppm")
export("update.lppm")
export("update.ppm")
export("update.rmhcontrol")
export("update.rmhstart")
export("update.slrm")
export("update.symbolmap")
export("valid")
export("validate2Dkernel")
export("validate.angles")        
export("validate.lpp.coords")
export("validate.mask")        
export("validate.quad")        
export("validate.weights")        
export("valid.detpointprocfamily")
export("valid.lppm")
export("valid.ppm")
export("validradius")
export("vanilla.fv")
export("varblock")
export("varcount")
export("varcountEngine")
export("vargamma.estK")
export("vargamma.estpcf")
export("vcov.kppm")
export("vcov.lppm")
export("vcov.mppm")
export("vcov.ppm")
export("vcov.slrm")
export("vdCorput")
export("verifyclass")
export("versionstring.interact")
export("versionstring.ppm")
export("versionstring.spatstat")
export("vertexdegree")
export("vertices")
export("vertices.linnet")
export("vertices.owin")
export("Vmark")
export("vnnFind")
export("volume")
export("volume.box3")
export("volume.boxx")
export("volume.linnet")
export("volume.owin")
export("warn.once")
export("waxlyrical")
export("weightedclosepairs")
export("weighted.median")
export("weighted.quantile")
export("weighted.var")
export("where.max")
export("where.min")
export("whichhalfplane")
export("which.max.im")
export("whist")
export("will.expand")
export("Window<-")
export("Window")
export("Window.distfun")
export("Window.dppm")
export("Window.funxy")
export("Window<-.im")
export("Window.im")
export("Window.influence.ppm")
export("Window.kppm")
export("Window.layered")
export("Window.leverage.ppm")
export("Window<-.linnet")
export("Window.linnet")
export("Window.lintess")
export("Window<-.lpp")
export("Window.lpp")
export("Window.lppm")
export("Window.msr")
export("Window.nnfun")
export("Window.ppm")
export("Window<-.ppp")
export("Window.ppp")
export("Window<-.psp")
export("Window.psp")
export("Window.quad")
export("Window.quadratcount")
export("Window.quadrattest")
export("Window.rmhmodel")
export("windows.mppm")
export("Window.tess")
export("with.fv")
export("with.hyperframe")
export("with.msr")
export("with.ssf")
export("w.quad")               
export("X2testEngine")
export("x.quad")
export("xtfrm.im")
export("xy.grid")
export("xypolygon2psp")
export("xypolyselfint")
export("yardstick")
export("y.quad")
export("zapsmall.im")
export("zclustermodel")

# .......  Special cases ........... 
export("%(-)%")
export("%(+)%")
export("%mapp%")
export("%mark%")
export("%mrep%")
export("%msub%")
export("%unit%")
S3method("Complex", "im")
S3method("Complex", "imlist")
S3method("Complex", "linim")
S3method("Math", "im")
S3method("Math", "imlist")
S3method("Math", "linim")
S3method("Math", "sparse3Darray")
S3method("mean", "im")
S3method("median", "im")
S3method("Ops", "im")
S3method("Ops", "imlist")
S3method("Ops", "linim")
S3method("Ops", "msr")
S3method("Ops", "sparse3Darray")
S3method("Summary", "im")
S3method("Summary", "imlist")
S3method("Summary", "linim")
S3method("Summary", "sparse3Darray")
# .......  End of special cases  ... 

# ......................................... 
# Automatically generated list of S3 methods
# ......................................... 
  S3method("affine", "im")
  S3method("affine", "layered")
  S3method("affine", "linim")
  S3method("affine", "linnet")
  S3method("affine", "lpp")
  S3method("affine", "owin")
 S3method("affine", "ppp")
 S3method("affine", "psp")
  S3method("affine", "tess")
S3method("AIC", "dppm")
S3method("AIC", "kppm")
 S3method("AIC", "mppm")
S3method("AIC", "ppm")
  S3method("anova", "lppm")
  S3method("anova", "mppm")
  S3method("anova", "ppm")
  S3method("anova", "slrm")
 S3method("anyDuplicated", "ppp")
 S3method("anyDuplicated", "ppx")
  S3method("[", "anylist")
  S3method("anyNA", "im")
S3method("anyNA", "sparse3Darray")
S3method("aperm", "sparse3Darray")
 S3method("area", "default")
 S3method("area", "owin")
  S3method("as.array", "im")
S3method("as.array", "sparse3Darray")
S3method("as.character", "unitname")
S3method("as.data.frame", "bw.optim")
S3method("as.data.frame", "envelope")
S3method("as.data.frame", "fv")
S3method("as.data.frame", "hyperframe")
  S3method("as.data.frame", "im")
  S3method("as.data.frame", "linfun")
  S3method("as.data.frame", "linim")
S3method("as.data.frame", "owin")
S3method("as.data.frame", "ppp")
S3method("as.data.frame", "ppx")
S3method("as.data.frame", "psp")
S3method("as.data.frame", "tess")
S3method("as.double", "im")
  S3method("as.function", "fv")
 S3method("as.function", "im")
 S3method("as.function", "leverage.ppm")
  S3method("as.function", "linfun")
 S3method("as.function", "owin")
  S3method("as.function", "rhohat")
  S3method("as.function", "ssf")
  S3method("as.function", "tess")
  S3method("as.fv", "bw.optim")
  S3method("as.fv", "data.frame")
  S3method("as.fv", "dppm")
  S3method("as.fv", "fasp")
  S3method("as.fv", "fv")
  S3method("as.fv", "kppm")
  S3method("as.fv", "matrix")
  S3method("as.fv", "minconfit")
S3method("as.hyperframe", "anylist")
S3method("as.hyperframe", "data.frame")
S3method("as.hyperframe", "default")
S3method("as.hyperframe", "hyperframe")
S3method("as.hyperframe", "listof")
S3method("as.hyperframe", "ppx")
  S3method("as.im", "data.frame")
  S3method("as.im", "default")
  S3method("as.im", "distfun")
  S3method("as.im", "function")
  S3method("as.im", "funxy")
  S3method("as.im", "im")
  S3method("as.im", "leverage.ppm")
  S3method("as.im", "linim")
  S3method("as.im", "matrix")
  S3method("as.im", "nnfun")
  S3method("as.im", "owin")
S3method("as.im", "ppp")
 S3method("as.im", "scan.test")
  S3method("as.im", "Smoothfun")
  S3method("as.im", "ssf")
  S3method("as.im", "tess")
S3method("as.interact", "fii")
S3method("as.interact", "interact")
S3method("as.interact", "ppm")
 S3method("as.layered", "default")
 S3method("as.layered", "listof")
 S3method("as.layered", "msr")
 S3method("as.layered", "ppp")
 S3method("as.layered", "solist")
 S3method("as.layered", "splitppp")
S3method("as.linfun", "linfun")
  S3method("as.linfun", "linim")
  S3method("as.linfun", "lintess")
  S3method("as.linim", "default")
  S3method("as.linim", "linfun")
  S3method("as.linim", "linim")
 S3method("as.linnet", "linfun")
 S3method("as.linnet", "linim")
S3method("as.linnet", "linnet")
 S3method("as.linnet", "lintess")
 S3method("as.linnet", "lpp")
  S3method("as.linnet", "lppm")
 S3method("as.linnet", "psp")
S3method("as.list", "hyperframe")
  S3method("as.matrix", "im")
  S3method("as.matrix", "owin")
S3method("as.matrix", "ppx")
 S3method("as.owin", "boxx")
 S3method("as.owin", "data.frame")
 S3method("as.owin", "default")
 S3method("as.owin", "distfun")
 S3method("as.owin", "dppm")
 S3method("as.owin", "funxy")
 S3method("as.owin", "im")
 S3method("as.owin", "influence.ppm")
 S3method("as.owin", "kppm")
 S3method("as.owin", "layered")
 S3method("as.owin", "leverage.ppm")
  S3method("as.owin", "linfun")
S3method("as.owin", "linnet")
S3method("as.owin", "lintess")
 S3method("as.owin", "lpp")
 S3method("as.owin", "lppm")
 S3method("as.owin", "msr")
 S3method("as.owin", "nnfun")
 S3method("as.owin", "owin")
 S3method("as.owin", "ppm")
 S3method("as.owin", "ppp")
 S3method("as.owin", "psp")
 S3method("as.owin", "quad")
 S3method("as.owin", "quadratcount")
 S3method("as.owin", "quadrattest")
 S3method("as.owin", "rmhmodel")
 S3method("as.owin", "tess")
S3method("as.ppm", "dppm")
S3method("as.ppm", "kppm")
S3method("as.ppm", "lppm")
S3method("as.ppm", "ppm")
S3method("as.ppm", "profilepl")
S3method("as.ppm", "rppm")
  S3method("as.ppp", "data.frame")
  S3method("as.ppp", "default")
  S3method("as.ppp", "influence.ppm")
S3method("as.ppp", "lpp")
  S3method("as.ppp", "matrix")
  S3method("as.ppp", "ppp")
  S3method("as.ppp", "psp")
  S3method("as.ppp", "quad")
  S3method("as.ppp", "ssf")
  S3method("as.psp", "data.frame")
  S3method("as.psp", "default")
S3method("as.psp", "linnet")
S3method("as.psp", "lpp")
  S3method("as.psp", "matrix")
S3method("as.psp", "owin")
  S3method("as.psp", "psp")
 S3method("as.tess", "im")
 S3method("as.tess", "list")
 S3method("as.tess", "owin")
 S3method("as.tess", "quadratcount")
 S3method("as.tess", "quadrattest")
 S3method("as.tess", "tess")
S3method("auc", "kppm")
S3method("auc", "lpp")
S3method("auc", "lppm")
S3method("auc", "ppm")
S3method("auc", "ppp")
  S3method("bc", "ppm")
S3method("berman.test", "lpp")
S3method("berman.test", "lppm")
S3method("berman.test", "ppm")
S3method("berman.test", "ppp")
S3method("boundingbox", "default")
S3method("boundingbox", "im")
S3method("boundingbox", "linnet")
S3method("boundingbox", "lpp")
S3method("boundingbox", "owin")
S3method("boundingbox", "ppp")
S3method("boundingbox", "psp")
S3method("boundingbox", "solist")
S3method("boundingcentre", "owin")
S3method("boundingcentre", "ppp")
S3method("boundingcircle", "owin")
S3method("boundingcircle", "ppp")
S3method("boundingradius", "linnet")
S3method("boundingradius", "owin")
S3method("boundingradius", "ppp")
S3method("by", "im")
 S3method("by", "ppp")
S3method("cbind", "fv")
S3method("cbind", "hyperframe")
S3method("CDF", "density")
S3method("cdf.test", "lpp")
S3method("cdf.test", "lppm")
S3method("cdf.test", "mppm")
S3method("cdf.test", "ppm")
S3method("cdf.test", "ppp")
S3method("cdf.test", "slrm")
S3method("circumradius", "linnet")
S3method("circumradius", "owin")
S3method("circumradius", "ppp")
S3method("closepairs", "pp3")
S3method("closepairs", "ppp")
 S3method("closing", "owin")
 S3method("closing", "ppp")
 S3method("closing", "psp")
  S3method("clusterfield", "character")
  S3method("clusterfield", "function")
  S3method("clusterfield", "kppm")
S3method("clusterkernel", "character")
S3method("clusterkernel", "kppm")
S3method("clusterradius", "character")
S3method("clusterradius", "kppm")
S3method("coef", "dppm")
S3method("coef", "fii")
S3method("coef", "kppm")
  S3method("coef", "lppm")
  S3method("coef", "mppm")
  S3method("coef", "ppm")
  S3method("coef", "slrm")
S3method("coef", "summary.fii")
S3method("coef", "summary.kppm")
S3method("coef", "summary.ppm")
S3method("coef", "vblogit")
S3method("collapse", "anylist")
S3method("collapse", "fv")
  S3method("compatible", "fasp")
  S3method("compatible", "fv")
 S3method("compatible", "im")
S3method("compatible", "rat")
  S3method("compatible", "unitname")
S3method("connected", "im")
S3method("connected", "linnet")
S3method("connected", "lpp")
S3method("connected", "owin")
S3method("connected", "pp3")
S3method("connected", "ppp")
S3method("contour", "funxy")
   S3method("contour", "im")
  S3method("contour", "imlist")
  S3method("contour", "listof")
S3method("contour", "objsurf")
S3method("contour", "ssf")
  S3method("coords", "ppp")
  S3method("coords", "ppx")
  S3method("crossdist", "default")
  S3method("crossdist", "lpp")
  S3method("crossdist", "pp3")
  S3method("crossdist", "ppp")
  S3method("crossdist", "ppx")
  S3method("crossdist", "psp")
S3method("crosspairs", "pp3")
S3method("crosspairs", "ppp")
  S3method("cut", "im")
  S3method("cut", "lpp")
  S3method("cut", "ppp")
S3method("deletebranch", "linnet")
S3method("deletebranch", "lpp")
  S3method("density", "linnet")
S3method("density", "lpp")
  S3method("density", "ppp")
  S3method("density", "ppplist")
  S3method("density", "psp")
  S3method("density", "splitppp")
S3method("density", "splitppx")
S3method("deriv", "fv")
  S3method("deviance", "lppm")
S3method("deviance", "ppm")
S3method("dfbetas", "ppm")
S3method("[", "diagramobj")
S3method("diameter", "box3")
S3method("diameter", "boxx")
S3method("diameter", "linnet")
 S3method("diameter", "owin")
 S3method("dilation", "owin")
 S3method("dilation", "ppp")
 S3method("dilation", "psp")
  S3method("dim", "detpointprocfamily")
S3method("dim", "fasp")
S3method("dim", "hyperframe")
S3method("dim", "im")
S3method("dim", "msr")
S3method("dimnames", "fasp")
S3method("dimnames", "msr")
S3method("dimnames", "sparse3Darray")
S3method("dim", "owin")
S3method("dim", "sparse3Darray")
  S3method("distfun", "lpp")
  S3method("distfun", "owin")
  S3method("distfun", "ppp")
  S3method("distfun", "psp")
  S3method("distmap", "owin")
  S3method("distmap", "ppp")
  S3method("distmap", "psp")
 S3method("domain", "distfun")
 S3method("domain", "dppm")
 S3method("domain", "funxy")
   S3method("domain", "im")
 S3method("domain", "im")
 S3method("domain", "influence.ppm")
 S3method("domain", "kppm")
 S3method("domain", "layered")
 S3method("domain", "leverage.ppm")
 S3method("domain", "linfun")
 S3method("domain", "lintess")
   S3method("domain", "lpp")
 S3method("domain", "lpp")
 S3method("domain", "lppm")
 S3method("domain", "msr")
 S3method("domain", "nnfun")
   S3method("domain", "pp3")
 S3method("domain", "ppm")
   S3method("domain", "ppp")
   S3method("domain", "ppx")
   S3method("domain", "psp")
 S3method("domain", "quad")
 S3method("domain", "quadratcount")
 S3method("domain", "quadrattest")
 S3method("domain", "rmhmodel")
 S3method("domain", "tess")
 S3method("duplicated", "ppp")
 S3method("duplicated", "ppx")
S3method("edit", "hyperframe")
S3method("edit", "im")
S3method("edit", "ppp")
S3method("edit", "psp")
  S3method("emend", "lppm")
S3method("emend", "ppm")
S3method("envelope", "envelope")
S3method("envelope", "hasenvelope")
  S3method("envelope", "kppm")
  S3method("envelope", "lpp")
  S3method("envelope", "lppm")
S3method("envelope", "matrix")
  S3method("envelope", "pp3")
  S3method("envelope", "ppm")
  S3method("envelope", "ppp")
S3method("eroded.volumes", "box3")
S3method("eroded.volumes", "boxx")
 S3method("erosion", "owin")
 S3method("erosion", "ppp")
 S3method("erosion", "psp")
S3method("evalCovar", "lppm")
S3method("evalCovar", "ppm")
S3method("extractAIC", "dppm")
S3method("extractAIC", "kppm")
  S3method("extractAIC", "lppm")
 S3method("extractAIC", "mppm")
S3method("extractAIC", "ppm")
S3method("extractAIC", "slrm")
S3method("extractbranch", "linnet")
S3method("extractbranch", "lpp")
S3method("family", "vblogit")
  S3method("fardist", "owin")
  S3method("fardist", "ppp")
  S3method("[", "fasp")
S3method("fitin", "ppm")
S3method("fitin", "profilepl")
  S3method("fitted", "dppm")
  S3method("fitted", "kppm")
S3method("fitted", "lppm")
 S3method("fitted", "mppm")
  S3method("fitted", "ppm")
S3method("fitted", "rppm")
  S3method("fitted", "slrm")
 S3method("fixef", "mppm")
 S3method("flipxy", "im")
S3method("flipxy", "infline")
  S3method("flipxy", "layered")
 S3method("flipxy", "owin")
 S3method("flipxy", "ppp")
 S3method("flipxy", "psp")
S3method("format", "numberwithunit")
S3method("formula", "dppm")
S3method("formula", "fv")
S3method("formula", "kppm")
  S3method("formula", "lppm")
S3method("formula", "ppm")
S3method("formula", "slrm")
   S3method("Frame", "default")
  S3method("[", "fv")
 S3method("getCall", "mppm")
S3method("harmonise", "fv")
S3method("harmonise", "im")
S3method("harmonise", "msr")
S3method("harmonise", "owin")
  S3method("harmonise", "unitname")
S3method("harmonize", "fv")
S3method("harmonize", "im")
S3method("harmonize", "owin")
  S3method("harmonize", "unitname")
  S3method("has.close", "default")
  S3method("has.close", "pp3")
  S3method("has.close", "ppp")
S3method("head", "hyperframe")
  S3method("head", "ppp")
  S3method("head", "ppx")
  S3method("head", "psp")
  S3method("head", "tess")
  S3method("hist", "funxy")
  S3method("hist", "im")
  S3method("[", "hyperframe")
  S3method("$", "hyperframe")
  S3method("identify", "lpp")
  S3method("identify", "ppp")
  S3method("identify", "psp")
  S3method("[", "im")
  S3method("image", "im")
  S3method("image", "imlist")
  S3method("image", "listof")
S3method("image", "objsurf")
S3method("image", "ssf")
  S3method("[", "influence.ppm")
S3method("influence", "ppm")
S3method("integral", "im")
S3method("integral", "linfun")
S3method("integral", "linim")
S3method("integral", "msr")
  S3method("integral", "ssf")
  S3method("intensity", "detpointprocfamily")
  S3method("intensity", "dppm")
S3method("intensity", "lpp")
S3method("intensity", "ppm")
S3method("intensity", "ppp")
  S3method("intensity", "ppx")
S3method("intensity", "psp")
S3method("intensity", "quadratcount")
S3method("intensity", "splitppp")
 S3method("iplot", "default")
 S3method("iplot", "layered")
 S3method("iplot", "linnet")
 S3method("iplot", "lpp")
 S3method("iplot", "ppp")
S3method("is.connected", "default")
S3method("is.connected", "linnet")
S3method("is.connected", "ppp")
S3method("is.empty", "default")
S3method("is.empty", "owin")
S3method("is.empty", "ppp")
S3method("is.empty", "psp")
S3method("is.expandable", "ppm")
S3method("is.expandable", "rmhmodel")
S3method("is.hybrid", "interact")
S3method("is.hybrid", "ppm")
S3method("is.marked", "default")
  S3method("is.marked", "lppm")
S3method("is.marked", "msr")
  S3method("is.marked", "ppm")
  S3method("is.marked", "ppp")
S3method("is.marked", "psp")
S3method("is.marked", "quad")
S3method("is.multitype", "default")
  S3method("is.multitype", "lpp")
  S3method("is.multitype", "lppm")
S3method("is.multitype", "msr")
  S3method("is.multitype", "ppm")
  S3method("is.multitype", "ppp")
S3method("is.multitype", "quad")
S3method("is.poisson", "interact")
S3method("is.poisson", "kppm")
S3method("is.poisson", "lppm")
S3method("is.poisson", "mppm")
S3method("is.poisson", "ppm")
S3method("is.poisson", "rmhmodel")
S3method("is.poisson", "slrm")
S3method("is.stationary", "detpointprocfamily")
S3method("is.stationary", "dppm")
S3method("is.stationary", "kppm")
S3method("is.stationary", "lppm")
S3method("is.stationary", "ppm")
S3method("is.stationary", "rmhmodel")
S3method("is.stationary", "slrm")
   S3method("Kmodel", "detpointprocfamily")
   S3method("Kmodel", "dppm")
   S3method("Kmodel", "kppm")
   S3method("Kmodel", "ppm")
  S3method("kppm", "formula")
  S3method("kppm", "ppp")
S3method("kppm", "quad")
S3method("labels", "dppm")
S3method("labels", "kppm")
S3method("labels", "ppm")
S3method("labels", "slrm")
  S3method("[", "layered")
S3method("levels", "im")
  S3method("[", "leverage.ppm")
S3method("leverage", "ppm")
  S3method("[", "linim")
  S3method("[", "linnet")
S3method("[", "localpcfmatrix")
S3method("logLik", "dppm")
S3method("logLik", "kppm")
  S3method("logLik", "lppm")
 S3method("logLik", "mppm")
S3method("logLik", "ppm")
  S3method("logLik", "slrm")
S3method("logLik", "vblogit")
  S3method("[", "lpp")
S3method("lppm", "formula")
S3method("lppm", "lpp")
S3method("markformat", "default")
S3method("markformat", "ppp")
S3method("markformat", "ppx")
S3method("markformat", "psp")
S3method("marks", "default")
S3method("marks", "ppp")
S3method("marks", "ppx")
S3method("marks", "psp")
S3method("marks", "quad")
  S3method("marks", "ssf")
S3method("marks", "tess")
  S3method("max", "fv")
  S3method("max", "ssf")
  S3method("mean", "linim")
  S3method("median", "linim")
  S3method("min", "fv")
  S3method("min", "ssf")
 S3method("model.frame", "dppm")
 S3method("model.frame", "kppm")
 S3method("model.frame", "lppm")
 S3method("model.frame", "ppm")
  S3method("model.images", "dppm")
  S3method("model.images", "kppm")
  S3method("model.images", "lppm")
  S3method("model.images", "ppm")
  S3method("model.images", "slrm")
   S3method("model.matrix", "dppm")
   S3method("model.matrix", "ippm")
   S3method("model.matrix", "kppm")
   S3method("model.matrix", "lppm")
   S3method("model.matrix", "ppm")
   S3method("model.matrix", "slrm")
S3method("[", "msr")
 S3method("multiplicity", "data.frame")
 S3method("multiplicity", "default")
 S3method("multiplicity", "ppp")
 S3method("multiplicity", "ppx")
S3method("names", "hyperframe")
  S3method("nnclean", "pp3")
  S3method("nnclean", "ppp")
  S3method("nncross", "default")
  S3method("nncross", "lpp")
  S3method("nncross", "pp3")
  S3method("nncross", "ppp")
S3method("nndensity", "ppp")
  S3method("nndist", "default")
S3method("nndist", "lpp")
  S3method("nndist", "pp3")
  S3method("nndist", "ppp")
  S3method("nndist", "ppx")
  S3method("nndist", "psp")
  S3method("nnfun", "lpp")
  S3method("nnfun", "ppp")
  S3method("nnfun", "psp")
  S3method("nnwhich", "default")
S3method("nnwhich", "lpp")
  S3method("nnwhich", "pp3")
  S3method("nnwhich", "ppp")
  S3method("nnwhich", "ppx")
  S3method("nobjects", "ppp")
  S3method("nobjects", "ppx")
  S3method("nobjects", "psp")
  S3method("nobjects", "tess")
S3method("nobs", "dppm")
S3method("nobs", "kppm")
  S3method("nobs", "lppm")
 S3method("nobs", "mppm")
S3method("nobs", "ppm")
  S3method("npoints", "pp3")
  S3method("npoints", "ppp")
  S3method("npoints", "ppx")
S3method("nsegments", "linnet")
S3method("nsegments", "lpp")
   S3method("nsegments", "psp")
  S3method("nvertices", "default")
S3method("nvertices", "linnet")
  S3method("nvertices", "owin")
S3method("objsurf", "dppm")
S3method("objsurf", "kppm")
S3method("objsurf", "minconfit")
 S3method("opening", "owin")
 S3method("opening", "ppp")
 S3method("opening", "psp")
  S3method("[", "owin")
  S3method("pairdist", "default")
S3method("pairdist", "lpp")
  S3method("pairdist", "pp3")
  S3method("pairdist", "ppp")
  S3method("pairdist", "ppx")
  S3method("pairdist", "psp")
S3method("pairs", "im")
S3method("pairs", "linim")
S3method("pairs", "listof")
S3method("pairs", "solist")
S3method("parameters", "dppm")
S3method("parameters", "fii")
S3method("parameters", "interact")
S3method("parameters", "kppm")
S3method("parameters", "ppm")
S3method("parameters", "profilepl")
 S3method("pcf", "fasp")
  S3method("pcf", "fv")
   S3method("pcfmodel", "detpointprocfamily")
   S3method("pcfmodel", "dppm")
   S3method("pcfmodel", "kppm")
   S3method("pcfmodel", "ppm")
 S3method("pcfmodel", "zclustermodel")
  S3method("pcf", "ppp")
S3method("periodify", "owin")
S3method("periodify", "ppp")
S3method("periodify", "psp")
S3method("persp", "funxy")
  S3method("persp", "im")
 S3method("persp", "leverage.ppm")
S3method("persp", "objsurf")
S3method("pixellate", "linnet")
S3method("pixellate", "owin")
S3method("pixellate", "ppp")
S3method("pixellate", "psp")
S3method("plot", "addvar")
  S3method("plot", "anylist")
S3method("plot", "barplotdata")
S3method("plot", "bermantest")
S3method("plot", "bw.frac")
S3method("plot", "bw.optim")
S3method("plot", "cdftest")
S3method("plot", "colourmap")
  S3method("plot", "diagppm")
  S3method("plot", "dppm")
 S3method("plot", "envelope")
   S3method("plot", "fasp")
S3method("plot", "fii")
S3method("plot", "foo")
S3method("plot", "funxy")
 S3method("plot", "fv")
   S3method("plot", "hyperframe")
  S3method("plot", "im")
  S3method("plot", "imlist")
S3method("plot", "infline")
 S3method("plot", "influence.ppm")
  S3method("plot", "kppm")
S3method("plot", "kstest")
S3method("plot", "laslett")
S3method("plot", "layered")
 S3method("plot", "leverage.ppm")
  S3method("plot", "linfun")
S3method("plot", "linim")
 S3method("plot", "linnet")
S3method("plot", "lintess")
  S3method("plot", "listof")
S3method("plot", "localpcfmatrix")
S3method("plot", "lpp")
  S3method("plot", "lppm")
S3method("plot", "lurk")
S3method("plot", "minconfit")
  S3method("plot", "mppm")
  S3method("plot", "msr")
S3method("plot", "objsurf")
 S3method("plot", "onearrow")
 S3method("plot", "owin")
S3method("plot", "parres")
S3method("plot", "plotpairsim")
  S3method("plot", "plotppm")
 S3method("plot", "pp3")
  S3method("plot", "ppm")
 S3method("plot", "ppp")
S3method("plot", "pppmatching")
S3method("plot", "ppx")
S3method("plot", "profilepl")
  S3method("plot", "psp")
S3method("plot", "qqppm")
  S3method("plot", "quad")
S3method("plot", "quadratcount")
 S3method("plot", "quadrattest")
S3method("plot", "rho2hat")
S3method("plot", "rhohat")
S3method("plot", "rppm")
 S3method("plot", "scan.test")
  S3method("plot", "slrm")
  S3method("plot", "solist")
S3method("plot", "spatialcdf")
  S3method("plot", "splitppp")
S3method("plot", "ssf")
S3method("plot", "studpermutest")
S3method("plot", "symbolmap")
  S3method("plot", "tess")
S3method("plot", "textstring")
 S3method("plot", "texturemap")
 S3method("plot", "yardstick")
S3method("points", "lpp")
S3method("pool", "anylist")
S3method("pool", "envelope")
S3method("pool", "fasp")
S3method("pool", "fv")
S3method("pool", "quadrattest")
S3method("pool", "rat")
S3method("[", "pp3")
S3method("ppm", "default")
   S3method("ppm", "formula")
   S3method("ppm", "ppp")
   S3method("ppm", "quad")
  S3method("[", "ppp")
  S3method("[", "ppx")
  S3method("predict", "dppm")
  S3method("predict", "kppm")
S3method("predict", "lppm")
S3method("predict", "mppm")
   S3method("predict", "ppm")
S3method("predict", "profilepl")
S3method("predict", "rho2hat")
S3method("predict", "rhohat")
S3method("predict", "rppm")
 S3method("predict", "slrm")
S3method("predict", "vblogit")
 S3method("predict", "zclustermodel")
S3method("print", "addvar")
S3method("print", "anylist")
S3method("print", "autoexec")
  S3method("print", "box3")
  S3method("print", "boxx")
S3method("print", "bt.frame")
S3method("print", "bugtable")
S3method("print", "bw.frac")
S3method("print", "bw.optim")
S3method("print", "colourmap")
S3method("print", "detpointprocfamily")
S3method("print", "detpointprocfamilyfun")
S3method("print", "diagppm")
S3method("print", "distfun")
S3method("print", "dppm")
S3method("print", "envelope")
S3method("print", "ewcdf")
S3method("print", "fasp")
S3method("print", "fii")
S3method("print", "funxy")
S3method("print", "fv")
S3method("print", "fvfun")
S3method("print", "hasenvelope")
S3method("print", "hierarchicalordering")
S3method("print", "hyperframe")
  S3method("print", "im")
S3method("print", "indicfun")
S3method("print", "infline")
S3method("print", "influence.ppm")
S3method("print", "interact")
S3method("print", "intermaker")
S3method("print", "isf")
S3method("print", "kppm")
S3method("print", "laslett")
S3method("print", "layered")
S3method("print", "leverage.ppm")
  S3method("print", "linfun")
  S3method("print", "linim")
S3method("print", "linnet")
S3method("print", "lintess")
S3method("print", "localpcfmatrix")
S3method("print", "lpp")
  S3method("print", "lppm")
S3method("print", "lut")
S3method("print", "minconfit")
S3method("print", "mppm")
S3method("print", "msr")
S3method("print", "nnfun")
S3method("print", "numberwithunit")
S3method("print", "objsurf")
S3method("print", "onearrow")
  S3method("print", "owin")
S3method("print", "parres")
S3method("print", "plotpairsim")
S3method("print", "plotppm")
  S3method("print", "pp3")
 S3method("print", "ppm")
  S3method("print", "ppp")
S3method("print", "pppmatching")
S3method("print", "ppx")
S3method("print", "profilepl")
  S3method("print", "psp")
S3method("print", "qqppm")
 S3method("print", "quad")
S3method("print", "quadrattest")
S3method("print", "rat")
S3method("print", "rho2hat")
S3method("print", "rhohat")
S3method("print", "rmhcontrol")
S3method("print", "rmhexpand")
S3method("print", "rmhInfoList")
S3method("print", "rmhmodel")
S3method("print", "rmhstart")
S3method("print", "rppm")
S3method("print", "simplepanel")
S3method("print", "slrm")
S3method("print", "Smoothfun")
S3method("print", "solist")
S3method("print", "sparse3Darray")
S3method("print", "splitppp")
S3method("print", "splitppx")
  S3method("print", "ssf")
S3method("print", "summary.fii")
S3method("print", "summary.hyperframe")
  S3method("print", "summary.im")
  S3method("print", "summary.kppm")
S3method("print", "summary.linim")
S3method("print", "summary.linnet")
S3method("print", "summary.lintess")
S3method("print", "summary.listof")
S3method("print", "summary.logiquad")
S3method("print", "summary.lpp")
S3method("print", "summary.lut")
S3method("print", "summary.mppm")
S3method("print", "summary.owin")
  S3method("print", "summary.pp3")
  S3method("print", "summary.ppm")
S3method("print", "summary.ppp")
S3method("print", "summary.psp")
  S3method("print", "summary.quad")
S3method("print", "summary.rmhexpand")
S3method("print", "summary.solist")
S3method("print", "summary.splitppp")
S3method("print", "summary.splitppx")
S3method("print", "summary.unitname")
S3method("print", "symbolmap")
S3method("print", "tess")
S3method("print", "textstring")
S3method("print", "texturemap")
S3method("print", "timed")
  S3method("print", "unitname")
S3method("print", "vblogit")
S3method("print", "yardstick")
 S3method("print", "zclustermodel")
S3method("prune", "rppm")
  S3method("pseudoR2", "lppm")
  S3method("pseudoR2", "ppm")
  S3method("psib", "kppm")
  S3method("[", "psp")
  S3method("[", "quad")
  S3method("quadratcount", "ppp")
  S3method("quadratcount", "splitppp")
  S3method("quadrat.test", "mppm")
S3method("quadrat.test", "ppm")
S3method("quadrat.test", "ppp")
S3method("quadrat.test", "quadratcount")
S3method("quadrat.test", "splitppp")
S3method("quantess", "im")
S3method("quantess", "owin")
S3method("quantess", "ppp")
S3method("quantile", "density")
  S3method("quantile", "ewcdf")
S3method("quantile", "im")
  S3method("quantile", "linim")
 S3method("ranef", "mppm")
  S3method("range", "fv")
  S3method("range", "ssf")
S3method("[", "rat")
S3method("rbind", "hyperframe")
  S3method("reach", "detpointprocfamily")
  S3method("reach", "dppm")
  S3method("reach", "fii")
  S3method("reach", "interact")
  S3method("reach", "ppm")
  S3method("reach", "rmhmodel")
S3method("rebound", "im")
S3method("rebound", "owin")
S3method("rebound", "ppp")
S3method("rebound", "psp")
  S3method("reflect", "default")
  S3method("reflect", "im")
S3method("reflect", "infline")
  S3method("reflect", "layered")
  S3method("reflect", "tess")
  S3method("relevel", "im")
  S3method("relevel", "ppp")
  S3method("relevel", "ppx")
S3method("relrisk", "ppm")
S3method("relrisk", "ppp")
 S3method("rescale", "im")
  S3method("rescale", "layered")
  S3method("rescale", "linnet")
  S3method("rescale", "lpp")
  S3method("rescale", "owin")
 S3method("rescale", "ppp")
 S3method("rescale", "psp")
  S3method("rescale", "unitname")
  S3method("residuals", "dppm")
  S3method("residuals", "kppm")
S3method("residuals", "mppm")
  S3method("residuals", "ppm")
S3method("rhohat", "lpp")
S3method("rhohat", "lppm")
S3method("rhohat", "ppm")
S3method("rhohat", "ppp")
S3method("rhohat", "quad")
   S3method("rmhcontrol", "default")
S3method("rmhcontrol", "list")
S3method("rmhcontrol", "rmhcontrol")
   S3method("rmh", "default")
  S3method("rmhmodel", "default")
   S3method("rmhmodel", "list")
  S3method("rmhmodel", "ppm")
S3method("rmhmodel", "rmhmodel")
  S3method("rmh", "ppm")
   S3method("rmhstart", "default")
S3method("rmhstart", "list")
S3method("rmhstart", "rmhstart")
S3method("roc", "kppm")
S3method("roc", "lpp")
S3method("roc", "lppm")
S3method("roc", "ppm")
S3method("roc", "ppp")
S3method("rose", "default")
S3method("rose", "density")
S3method("rose", "fv")
S3method("rose", "histogram")
 S3method("rotate", "im")
S3method("rotate", "infline")
  S3method("rotate", "layered")
  S3method("rotate", "linnet")
  S3method("rotate", "lpp")
 S3method("rotate", "owin")
 S3method("rotate", "ppp")
 S3method("rotate", "psp")
  S3method("rotate", "tess")
S3method("rounding", "default")
S3method("rounding", "pp3")
S3method("rounding", "ppp")
S3method("rounding", "ppx")
S3method("round", "pp3")
S3method("round", "ppp")
S3method("round", "ppx")
S3method("row.names", "hyperframe")
   S3method("rshift", "ppp")
   S3method("rshift", "psp")
   S3method("rshift", "splitppp")
S3method("scalardilate", "breakpts")
  S3method("scalardilate", "default")
S3method("scalardilate", "diagramobj")
  S3method("scalardilate", "im")
  S3method("scalardilate", "layered")
  S3method("scalardilate", "linim")
  S3method("scalardilate", "linnet")
  S3method("scalardilate", "lpp")
S3method("scalardilate", "msr")
  S3method("scalardilate", "owin")
  S3method("scalardilate", "ppp")
  S3method("scalardilate", "psp")
  S3method("scalardilate", "tess")
  S3method("scaletointerval", "default")
  S3method("scaletointerval", "im")
S3method("scanmeasure", "im")
S3method("scanmeasure", "ppp")
S3method("segregation.test", "ppp")
S3method("sharpen", "ppp")
S3method("shift", "diagramobj")
 S3method("shift", "im")
S3method("shift", "infline")
S3method("shift", "influence.ppm")
  S3method("shift", "layered")
S3method("shift", "leverage.ppm")
  S3method("shift", "linim")
  S3method("shift", "linnet")
  S3method("shift", "lpp")
S3method("shift", "msr")
 S3method("shift", "owin")
 S3method("shift", "ppp")
 S3method("shift", "psp")
S3method("shift", "quadratcount")
S3method("shift", "quadrattest")
  S3method("shift", "tess")
S3method("shortside", "box3")
S3method("shortside", "boxx")
 S3method("shortside", "owin")
S3method("sidelengths", "box3")
S3method("sidelengths", "boxx")
 S3method("sidelengths", "owin")
  S3method("simulate", "detpointprocfamily")
  S3method("simulate", "dppm")
  S3method("simulate", "kppm")
  S3method("simulate", "lppm")
  S3method("simulate", "mppm")
  S3method("simulate", "ppm")
S3method("simulate", "profilepl")
S3method("simulate", "rhohat")
  S3method("simulate", "slrm")
S3method("Smoothfun", "ppp")
S3method("Smooth", "fv")
S3method("Smooth", "im")
 S3method("Smooth", "msr")
S3method("Smooth", "ppp")
S3method("Smooth", "solist")
 S3method("Smooth", "ssf")
  S3method("[", "solist")
S3method("sort", "im")
S3method("[", "sparse3Darray")
  S3method("split", "hyperframe")
S3method("split", "im")
  S3method("split", "msr")
  S3method("[", "splitppp")
  S3method("split", "ppp")
  S3method("split", "ppx")
S3method("[", "splitppx")
 S3method("[", "ssf")
S3method("str", "hyperframe")
S3method("subset", "hyperframe")
S3method("subset", "lpp")
S3method("subset", "pp3")
S3method("subset", "ppp")
S3method("subset", "ppx")
 S3method("summary", "anylist")
S3method("summary", "envelope")
S3method("summary", "fii")
S3method("summary", "funxy")
S3method("summary", "hyperframe")
  S3method("summary", "im")
  S3method("summary", "kppm")
  S3method("summary", "linfun")
  S3method("summary", "linim")
S3method("summary", "linnet")
S3method("summary", "lintess")
 S3method("summary", "listof")
S3method("summary", "logiquad")
S3method("summary", "lpp")
  S3method("summary", "lppm")
S3method("summary", "lut")
S3method("summary", "mppm")
  S3method("summary", "owin")
  S3method("summary", "pp3")
  S3method("summary", "ppm")
 S3method("summary", "ppp")
S3method("summary", "pppmatching")
S3method("summary", "ppx")
S3method("summary", "profilepl")
  S3method("summary", "psp")
  S3method("summary", "quad")
S3method("summary", "rmhexpand")
 S3method("summary", "solist")
 S3method("summary", "splitppp")
S3method("summary", "splitppx")
  S3method("summary", "unitname")
S3method("summary", "vblogit")
  S3method("superimpose", "default")
  S3method("superimpose", "lpp")
  S3method("superimpose", "ppp")
  S3method("superimpose", "ppplist")
  S3method("superimpose", "psp")
  S3method("superimpose", "splitppp")
S3method("tail", "hyperframe")
  S3method("tail", "ppp")
  S3method("tail", "ppx")
  S3method("tail", "psp")
  S3method("tail", "tess")
S3method("terms", "dppm")
S3method("terms", "kppm")
  S3method("terms", "lppm")
 S3method("terms", "mppm")
S3method("terms", "ppm")
S3method("terms", "slrm")
  S3method("[", "tess")
S3method("text", "lpp")
S3method("text", "ppp")
S3method("text", "psp")
 S3method("unique", "ppp")
 S3method("unique", "ppx")
  S3method("unitname", "box3")
  S3method("unitname", "boxx")
S3method("unitname", "default")
S3method("unitname", "dppm")
S3method("unitname", "im")
S3method("unitname", "kppm")
S3method("unitname", "linnet")
S3method("unitname", "lpp")
S3method("unitname", "minconfit")
S3method("unitname", "owin")
  S3method("unitname", "pp3")
S3method("unitname", "ppm")
S3method("unitname", "ppp")
S3method("unitname", "ppx")
S3method("unitname", "psp")
S3method("unitname", "quad")
S3method("unitname", "slrm")
S3method("unitname", "tess")
S3method("unmark", "lpp")
 S3method("unmark", "ppp")
 S3method("unmark", "ppx")
 S3method("unmark", "psp")
 S3method("unmark", "splitppp")
  S3method("unmark", "ssf")
S3method("unmark", "tess")
S3method("unstack", "layered")
S3method("unstack", "lpp")
S3method("unstack", "msr")
S3method("unstack", "ppp")
S3method("unstack", "psp")
S3method("unstack", "solist")
  S3method("update", "detpointprocfamily")
S3method("update", "im")
S3method("update", "interact")
S3method("update", "ippm")
 S3method("update", "kppm")
  S3method("update", "lppm")
  S3method("update", "ppm")
  S3method("update", "rmhcontrol")
S3method("update", "rmhstart")
S3method("update", "slrm")
S3method("update", "symbolmap")
   S3method("valid", "detpointprocfamily")
  S3method("valid", "lppm")
  S3method("valid", "ppm")
   S3method("vcov", "kppm")
  S3method("vcov", "lppm")
   S3method("vcov", "mppm")
  S3method("vcov", "ppm")
  S3method("vcov", "slrm")
S3method("vertices", "linnet")
 S3method("vertices", "owin")
S3method("volume", "box3")
S3method("volume", "boxx")
S3method("volume", "linnet")
 S3method("volume", "owin")
 S3method("Window", "distfun")
 S3method("Window", "dppm")
 S3method("Window", "funxy")
   S3method("Window", "im")
 S3method("Window", "influence.ppm")
 S3method("Window", "kppm")
 S3method("Window", "layered")
 S3method("Window", "leverage.ppm")
S3method("Window", "linnet")
S3method("Window", "lintess")
 S3method("Window", "lpp")
 S3method("Window", "lppm")
 S3method("Window", "msr")
 S3method("Window", "nnfun")
 S3method("Window", "ppm")
   S3method("Window", "ppp")
   S3method("Window", "psp")
 S3method("Window", "quad")
 S3method("Window", "quadratcount")
 S3method("Window", "quadrattest")
 S3method("Window", "rmhmodel")
 S3method("Window", "tess")
S3method("with", "fv")
S3method("with", "hyperframe")
S3method("with", "msr")
  S3method("with", "ssf")
S3method("xtfrm", "im")
# ......................................... 
#      Assignment methods                   
# ......................................... 
  S3method("[<-", "anylist")
  S3method("coords<-", "ppp")
  S3method("coords<-", "ppx")
S3method("dimnames<-", "fasp")
S3method("dimnames<-", "sparse3Darray")
S3method("dim<-", "sparse3Darray")
S3method("formula<-", "fv")
   S3method("Frame<-", "default")
   S3method("Frame<-", "im")
   S3method("Frame<-", "owin")
   S3method("Frame<-", "ppp")
  S3method("[<-", "fv")
  S3method("$<-", "fv")
  S3method("[<-", "hyperframe")
  S3method("$<-", "hyperframe")
  S3method("[<-", "im")
  S3method("[<-", "layered")
  S3method("[[<-", "layered")
S3method("levels<-", "im")
  S3method("[<-", "linim")
  S3method("[<-", "listof")
S3method("marks<-", "lpp")
S3method("marks<-", "ppp")
S3method("marks<-", "ppx")
S3method("marks<-", "psp")
  S3method("marks<-", "ssf")
S3method("marks<-", "tess")
S3method("names<-", "fv")
S3method("names<-", "hyperframe")
  S3method("[<-", "ppp")
S3method("row.names<-", "hyperframe")
  S3method("[<-", "solist")
S3method("[<-", "sparse3Darray")
  S3method("split<-", "hyperframe")
  S3method("[<-", "splitppp")
  S3method("split<-", "ppp")
S3method("[<-", "splitppx")
  S3method("[<-", "tess")
  S3method("unitname<-", "box3")
  S3method("unitname<-", "boxx")
S3method("unitname<-", "default")
S3method("unitname<-", "dppm")
S3method("unitname<-", "im")
S3method("unitname<-", "kppm")
S3method("unitname<-", "linnet")
S3method("unitname<-", "lpp")
S3method("unitname<-", "minconfit")
S3method("unitname<-", "owin")
  S3method("unitname<-", "pp3")
S3method("unitname<-", "ppm")
S3method("unitname<-", "ppp")
S3method("unitname<-", "ppx")
S3method("unitname<-", "psp")
S3method("unitname<-", "quad")
S3method("unitname<-", "slrm")
S3method("unitname<-", "tess")
   S3method("Window<-", "im")
S3method("Window<-", "linnet")
S3method("Window<-", "lpp")
   S3method("Window<-", "ppp")
   S3method("Window<-", "psp")
# ......................................... 
#      End of methods                       
# ......................................... 
